@@ -1,5 +1,7 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
+// SPDX-FileCopyrightInfo: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 /** \defgroup dom Domains
  * \ingroup ug
  */
@@ -64,27 +66,6 @@
 
 START_UGDIM_NAMESPACE
 
-/** \brief Offset of additional parameters for boundary condition function call */
-enum DOM_IN_PARAMS {
-
-  DOM_GLB_X,              /*!< General bnd cond. x-coordinate               */
-  DOM_GLB_Y,              /*!< General bnd cond. y-coordinate               */
-  DOM_GLB_Z,              /*!< General bnd cond. z-coordinate               */
-  DOM_EVAL_FOR_SD,        /*!< Evaluate bc for this subdomain               */
-  DOM_N_IN_PARAMS
-};
-
-#define DOM_LOC_X       DOM_GLB_X       /*!< Parametrized bnd cond. local x-coord.*/
-#define DOM_LOC_Y       DOM_GLB_Y       /*!< parametrized bnd cond. local y-coord.*/
-
-#define DOM_PARAM_OFFSET        DOM_N_IN_PARAMS
-
-/** \brief Subdomain of BC evaluation unknown */
-#define DOM_EVAL_SD_UNKNOWN             -1.0
-
-/** \brief Boundary types */
-enum BoundaryType {FIXED, FREE, PERIODIC, NON_PERIODIC};
-
 /** \brief Status for mesh */
 enum MeshStatus {MESHSTAT_NOTINIT,
                  MESHSTAT_EMPTY,
@@ -106,10 +87,7 @@ typedef INT (*UserProcPtr)(DOUBLE *, DOUBLE *);
 #define BVPD_RADIUS(d)       ((d)->radius)
 #define BVPD_CONVEX(d)       ((d)->convex)
 #define BVPD_NSUBDOM(d)      ((d)->nSubDomains)
-#define BVPD_NPARTS(d)       ((d)->nDomainParts)
 #define BVPD_CONFIG(d)       ((d)->ConfigProc)
-#define BVPD_S2P_PTR(d)      ((d)->s2p)
-#define BVPD_S2P(d,s)        ((d)->s2p[s])
 #define BVPD_NCOEFFF(d)      ((d)->numOfCoeffFct)
 #define BVPD_NUSERF(d)       ((d)->numOfUserFct)
 /*@}*/
@@ -137,12 +115,6 @@ struct BVP_Descriptor
   /*@{*/
   /** \brief Number of subdomains, exterior not counted                */
   INT nSubDomains;
-
-  /** \brief Number of parts in the domain               */
-  INT nDomainParts;
-
-  /** \brief Pointer to table subbdom --> part   */
-  INT *s2p;
   /*@}*/
 
   /** @name Problem part */
@@ -212,7 +184,7 @@ struct mesh
   /** @name Parallel part */
   /*@}*/
   /** \brief Level of vertex NULL if all vertex on level 0 */
-  char *VertexLevel;
+  unsigned char *VertexLevel;
 
   /** \brief Priority of vertex   NULL if all vertex are master               */
   char *VertexPrio;
@@ -392,23 +364,6 @@ INT         BVP_SetUserFct        (BVP *theBVP, INT n, UserProcPtr *UserFct);
 /****************************************************************************/
 INT             BVP_Check                         (BVP *aBVP);
 
-/****************************************************************************/
-/** \brief Sets a BNDP from command input
- *
- * @param theBVP - BVP structure
- * @param argc, argv - command parameters
-
-   This function sets a BNDP from command input parameters.
-   Options are implementation specific.
-
- * @return <ul>
- *   <li> 0 if ok </li>
- *   <li> 1 if error. </li>
- * </ul>
- */
-/****************************************************************************/
-BNDP* BVP_InsertBndP (NS_PREFIX HEAP *Heap, BVP *theBVP, INT argc, char **argv);
-
 /****************************************************************************/
 /** \brief Write command to insert this BNDP
  *
@@ -462,7 +417,6 @@ INT         BNDP_Move                         (BNDP *aBndP, const DOUBLE global[
  *
  * @param theBndP - BNDP structure
  * @param move  - movable flag (0: no, 1:yes)
- * @param part  - domain part
 
    This function sets the descriptor for a BNDP.
 
@@ -471,14 +425,13 @@ INT         BNDP_Move                         (BNDP *aBndP, const DOUBLE global[
  *   <li> 1 if error. </li>
  * </ul> */
 /****************************************************************************/
-INT         BNDP_BndPDesc         (BNDP *theBndP, INT *move, INT *part);
+INT         BNDP_BndPDesc         (BNDP *theBndP, INT *move);
 
 /****************************************************************************/
 /** \brief Sets descriptor for BNDE (boundary edge)
  *
  * @param theBndP0 - first BNDP
  * @param theBndP1 - second BNDP
- * @param part   - domain part ID
 
    This function sets the descriptor for a BNDE.
 
@@ -487,7 +440,7 @@ INT         BNDP_BndPDesc         (BNDP *theBndP, INT *move, INT *part);
  *   <li> 1 if error.
  * </ul> */
 /****************************************************************************/
-INT         BNDP_BndEDesc         (BNDP *theBndP0, BNDP *theBndP1, INT *part);
+INT         BNDP_BndEDesc         (BNDP *theBndP0, BNDP *theBndP1);
 
 /****************************************************************************/
 /** \brief Creates a BNDS from a nb of BNDPs
@@ -592,7 +545,6 @@ INT         BNDS_Global           (BNDS *theBndS, DOUBLE *local, DOUBLE *global)
  * @param theBndS - BNDS structure
  * @param id  - subdomain ID of the element with aBndS
  * @param nbid  - subdomain ID of the neighbour element (across the boundary)
- * @param part  - domain part
 
    This function sets the descriptor for a BNDS.
 
@@ -602,7 +554,7 @@ INT         BNDS_Global           (BNDS *theBndS, DOUBLE *local, DOUBLE *global)
  * </ul>
  */
 /****************************************************************************/
-INT         BNDS_BndSDesc         (BNDS *theBndS, INT *id, INT *nbid, INT *part);
+INT         BNDS_BndSDesc         (BNDS *theBndS, INT *id, INT *nbid);
 
 /****************************************************************************/
 /** \brief Create BNDP on BNDS
