@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 /****************************************************************************/
@@ -90,14 +92,6 @@ typedef struct {
   INT objt_used;             /**< Bitwise object ID				*/
 } CONTROL_ENTRY_PREDEF;
 
-typedef struct {
-
-  INT read;             /**< Number of accesses to read		*/
-  INT write;            /**< Number of accesses to write		*/
-  INT max;              /**< Max value assigned to ce			*/
-
-} CE_USAGE;
-
 /****************************************************************************/
 /*                                                                          */
 /* definition of exported global variables                                  */
@@ -227,8 +221,6 @@ static CONTROL_ENTRY_PREDEF ce_predefines[MAX_CONTROL_ENTRIES] = {
   CE_INIT_UNUSED,
 };
 
-static CE_USAGE ce_usage[MAX_CONTROL_ENTRIES];
-
 /****************************************************************************/
 /** \brief Print all control entries of an objects control word
 
@@ -471,7 +463,7 @@ void NS_DIM_PREFIX ListAllCWsOfAllObjectTypes (PrintfProcPtr myprintf)
 
  * @return <ul>
  * <li> GM_OK if ok </li>
- * <li> GM_ERROR if error occured </li>
+ * <li> GM_ERROR if error occurred </li>
  * </ul>
  */
 /****************************************************************************/
@@ -522,7 +514,7 @@ static INT InitPredefinedControlWords (void)
 
  * @return <ul>
  * <li> GM_OK if ok </li>
- * <li> GM_ERROR if error occured </li>
+ * <li> GM_ERROR if error occurred </li>
  * </ul>
  */
 /****************************************************************************/
@@ -665,9 +657,6 @@ UINT NS_DIM_PREFIX ReadCW (const void *obj, INT ceID)
     assert(false);
   }
 
-  /* update statistics */
-  ce_usage[ceID].read++;
-
   ce = control_entries+ceID;
 
   if (!ce->used)
@@ -738,10 +727,6 @@ void NS_DIM_PREFIX WriteCW (void *obj, INT ceID, INT n)
     assert(false);
   }
 
-  /* update statistics */
-  ce_usage[ceID].write++;
-  ce_usage[ceID].max = MAX(n,ce_usage[ceID].max);
-
   ce = control_entries+ceID;
 
   if (!ce->used)
@@ -837,7 +822,7 @@ void NS_DIM_PREFIX WriteCW (void *obj, INT ceID, INT n)
    @return
    </ul>
    <li>   GM_OK if ok </li>
-   <li>   GM_ERROR if error occured. </li>
+   <li>   GM_ERROR if error occurred. </li>
    </ul>
  */
 /****************************************************************************/
@@ -903,7 +888,7 @@ INT NS_DIM_PREFIX AllocateControlEntry (INT cw_id, INT length, INT *ce_id)
 
    @return <ul>
    <li>    GM_OK if ok </li>
-   <li>    GM_ERROR if error occured. </li>
+   <li>    GM_ERROR if error occurred. </li>
    </ul>
  */
 /****************************************************************************/
@@ -939,7 +924,7 @@ INT NS_DIM_PREFIX FreeControlEntry (INT ce_id)
 
    @return <ul>
    <li>  GM_OK if ok </li>
-   <li>  > 0 line in which error occured. </li>
+   <li>  > 0 line in which error occurred. </li>
    </ul>
  */
 /****************************************************************************/
