@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 /****************************************************************************/
@@ -78,7 +80,7 @@ INT NS_DIM_PREFIX reference2tag[MAX_CORNERS_OF_ELEM+1];
 /*																			*/
 /****************************************************************************/
 
-#ifdef __TWODIM__
+#ifdef UG_DIM_2
 static GENERAL_ELEMENT def_triangle = {
   3,                                                                                    /* tag							*/
   4,                                                                                    /* max number of sons			*/
@@ -111,7 +113,7 @@ static GENERAL_ELEMENT def_quadrilateral = {
 } ;
 #endif
 
-#ifdef __THREEDIM__
+#ifdef UG_DIM_3
 static GENERAL_ELEMENT def_tetrahedron = {
   4,                                                                                    /* tag							*/
   12,                                                                                   /* max number of sons			*/
@@ -249,7 +251,7 @@ static GENERAL_ELEMENT def_hexahedron = {
    Only the following components of the GENERAL_ELEMENT structure must be provided.
    All other components are derived from the given information.
 
-   . tag - New tag for the elememt which will be delivered by the 'TAG' macro.
+   . tag - New tag for the element which will be delivered by the 'TAG' macro.
    . max_sons_of_elem - Max number of sons allowed for that element type.
    . sides_of_elem - Number of sides for that element type.
    . corners_of_elem - Number of corners for that element type.
@@ -272,7 +274,7 @@ static GENERAL_ELEMENT def_hexahedron = {
 
    \return <ul>
    <li> GM_OK if ok </li>
-   <li> GM_ERROR if error occured </li>
+   <li> GM_ERROR if error occurred </li>
    <ul>
  */
 /****************************************************************************/
@@ -281,7 +283,7 @@ static INT PreProcessElementDescription (GENERAL_ELEMENT *el)
 {
   INT tag;
   INT i,j,k,l,n,from,to;
-        #ifdef __THREEDIM__
+        #ifdef UG_DIM_3
   INT m,n1,n2;
         #endif
 
@@ -371,7 +373,7 @@ static INT PreProcessElementDescription (GENERAL_ELEMENT *el)
     for (j=0; j<MAX_EDGES_OF_ELEM; j++)
       el->edge_of_corner[i][j] = -1;
 
-#ifdef __TWODIM__
+#ifdef UG_DIM_2
   switch (tag)
   {
   case TRIANGLE :
@@ -460,7 +462,7 @@ static INT PreProcessElementDescription (GENERAL_ELEMENT *el)
   }
 #endif
 
-#ifdef __THREEDIM__
+#ifdef UG_DIM_3
   /* edge_of_two_sides(i,j) */
   for (i=0; i<MAX_SIDES_OF_ELEM; i++)
     for (j=0; j<MAX_SIDES_OF_ELEM; j++)
@@ -790,7 +792,7 @@ static INT PreProcessElementDescription (GENERAL_ELEMENT *el)
 
    \return <ul>
    <li> GM_OK if ok </li>
-   <li> GM_ERROR if error occured. </li>
+   <li> GM_ERROR if error occurred. </li>
    </ul>
  */
 /****************************************************************************/
@@ -811,10 +813,10 @@ static INT ProcessElementDescription (MULTIGRID *theMG, GENERAL_ELEMENT *el)
   /* the sons */
   sons_offset[tag] = 0;
   /*
-     #ifdef __TWODIM__
+     #ifdef UG_DIM_2
                   sons_offset[tag] = p_count; p_count += el->max_sons_of_elem;
      #endif
-     #ifdef __THREEDIM__
+     #ifdef UG_DIM_3
                   sons_offset[tag] = p_count; p_count++;
      #endif
    */
@@ -832,15 +834,10 @@ static INT ProcessElementDescription (MULTIGRID *theMG, GENERAL_ELEMENT *el)
 
   /* element vector */
   evector_offset[tag] = 0;
-  if (VEC_DEF_IN_OBJ_OF_MG(theMG,ELEMVEC))
-  {
-    evector_offset[tag] = p_count;
-    p_count++;
-  }
 
   /* side vector */
   svector_offset[tag] = 0;
-        #ifdef __THREEDIM__
+        #ifdef UG_DIM_3
   if (VEC_DEF_IN_OBJ_OF_MG(theMG,SIDEVEC))
   {
     svector_offset[tag] = p_count;
@@ -876,7 +873,7 @@ static INT ProcessElementDescription (MULTIGRID *theMG, GENERAL_ELEMENT *el)
 
    \return <ul>
    <li> GM_OK if ok </li>
-   <li> GM_ERROR if error occured. </li>
+   <li> GM_ERROR if error occurred. </li>
    </ul>
  */
 /****************************************************************************/
@@ -885,14 +882,14 @@ INT NS_DIM_PREFIX PreInitElementTypes (void)
 {
   INT err;
 
-#ifdef __TWODIM__
+#ifdef UG_DIM_2
   err = PreProcessElementDescription(&def_triangle);
   if (err!=GM_OK) return(err);
   err = PreProcessElementDescription(&def_quadrilateral);
   if (err!=GM_OK) return(err);
 #endif
 
-#ifdef __THREEDIM__
+#ifdef UG_DIM_3
   err = PreProcessElementDescription(&def_tetrahedron);
   if (err!=GM_OK) return(err);
   err = PreProcessElementDescription(&def_pyramid);
@@ -915,7 +912,7 @@ INT NS_DIM_PREFIX PreInitElementTypes (void)
 
    \return <ul>
    <li> GM_OK if ok </li>
-   <li> GM_ERROR if error occured </li>
+   <li> GM_ERROR if error occurred </li>
    </ul>
  */
 /****************************************************************************/
@@ -927,14 +924,14 @@ INT NS_DIM_PREFIX InitElementTypes (MULTIGRID *theMG)
   if (theMG==NULL)
     return(GM_ERROR);
 
-#ifdef __TWODIM__
+#ifdef UG_DIM_2
   err = ProcessElementDescription(theMG,&def_triangle);
   if (err!=GM_OK) return(err);
   err = ProcessElementDescription(theMG,&def_quadrilateral);
   if (err!=GM_OK) return(err);
 #endif
 
-#ifdef __THREEDIM__
+#ifdef UG_DIM_3
   err = ProcessElementDescription(theMG,&def_tetrahedron);
   if (err!=GM_OK) return(err);
   err = ProcessElementDescription(theMG,&def_pyramid);
