@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 /****************************************************************************/
@@ -255,7 +257,7 @@ static struct {
     SYNOPSIS:
     static DOUBLE Corner2DCorners (INT n, SHORT corners[])
 
-    PAAMETERS:
+    PARAMETERS:
    .   n - number of corners
    .   corners - array of corner IDs
 
@@ -265,7 +267,7 @@ static struct {
 
     RETURN VALUE:
     DOUBLE
-   .n   coded coners
+   .n   coded corners
    doctext_disabled*/
 /****************************************************************************/
 
@@ -316,7 +318,6 @@ static void DCorners2Corners (INT n, DOUBLE dco, SHORT corners[])
     corners[i] = (SHORT)(dco-x*MAX_REFINED_CORNERS_DIM);
     dco = x;
   }
-  return;
 }
 
 /****************************************************************************/
@@ -364,7 +365,7 @@ static void FillOrderedSons (const ERULE *er, DOUBLE oco[])
     static INT Hash_Init (int MarkKey)
 
     PAAMETERS:
-   .   MarkKey - mark key for memory alocation
+   .   MarkKey - mark key for memory allocation
 
     DESCRIPTION:
         Allocate and initialize hash table
@@ -376,7 +377,7 @@ static void FillOrderedSons (const ERULE *er, DOUBLE oco[])
    doctext_disabled*/
 /****************************************************************************/
 
-#if (defined __THREEDIM__) || (defined __DEBUG_ER__)
+#if (defined UG_DIM_3) || (defined __DEBUG_ER__)
 static INT Hash_Init (int MarkKey)
 {
   int i;
@@ -505,7 +506,7 @@ static INT SonsAreEqual (INT nsons, const DOUBLE oco[], const HRULE *hr)
    doctext_disabled*/
 /****************************************************************************/
 
-#if (defined __THREEDIM__) || (defined __DEBUG_ER__)
+#if (defined UG_DIM_3) || (defined __DEBUG_ER__)
 static HRID GetRuleID
 (
         #ifdef Debug
@@ -732,7 +733,7 @@ static INT ExtractERule (ELEMENT *elem, ERULE *er)
    doctext_disabled*/
 /****************************************************************************/
 
-#if (defined __THREEDIM__) || (defined __DEBUG_ER__)
+#if (defined UG_DIM_3) || (defined __DEBUG_ER__)
 static int CountIFElements (DDD::DDDContext&, DDD_OBJ obj)
 {
   ELEMENT *elem = (ELEMENT*) obj;
@@ -1081,7 +1082,7 @@ static INT ExtractInterfaceRules (MULTIGRID *mg)
    doctext_disabled*/
 /****************************************************************************/
 
-#if (defined __THREEDIM__) || (defined __DEBUG_ER__)
+#if (defined UG_DIM_3) || (defined __DEBUG_ER__)
 static INT ExtractRules (MULTIGRID *mg)
 {
   ELEMENT *elem;
@@ -1161,7 +1162,9 @@ static INT ExtractRules (MULTIGRID *mg)
 
   if (maxrules>0)
   {
+#ifdef Debug
     int n = 0;
+#endif
     int max_list_len = 0;
 
     /* make tables of subsequent IDs */
@@ -1185,9 +1188,11 @@ static INT ExtractRules (MULTIGRID *mg)
       {
         global.hrule[HR_TAG(hr)][HR_ID(hr)] = hr;
         list_len++;
+#ifdef Debug
         n++;
+#endif
       }
-      max_list_len = MAX(max_list_len,list_len);
+      max_list_len = std::max(max_list_len,list_len);
     }
     ASSERT(maxrules==n);
 
@@ -1251,8 +1256,6 @@ static void FindPathForNeighbours (MGIO_RR_RULE *rule, SHORT myID, SHORT Status[
       Status[nbID] = NB_DONE;
       FindPathForNeighbours(rule,nbID,Status);
     }
-
-  return;
 }
 
 /****************************************************************************/
@@ -1273,7 +1276,7 @@ static void FindPathForNeighbours (MGIO_RR_RULE *rule, SHORT myID, SHORT Status[
    .n   none
    doctext_disabled*/
 /****************************************************************************/
-#ifdef __THREEDIM__
+#ifdef UG_DIM_3
 static void FillSonPaths (MGIO_RR_RULE *rule)
 {
   SHORT Status[MAX_SONS];
@@ -1290,8 +1293,6 @@ static void FillSonPaths (MGIO_RR_RULE *rule)
 
   /* start recursion with son 0 */
   FindPathForNeighbours(rule,0,Status);
-
-  return;
 }
 #endif
 /****************************************************************************/
@@ -1348,7 +1349,7 @@ static INT GetFSidesOfCorners (int tag, int n, SHORT corners[MAX_CORNERS_OF_SIDE
       /* edge mid node */
       int ed = corners[co]-coe;
 
-                        #ifdef __TWODIM__
+                        #ifdef UG_DIM_2
       corner_on_side[co][ed] = true;
                         #else
       int i;
@@ -1360,7 +1361,7 @@ static INT GetFSidesOfCorners (int tag, int n, SHORT corners[MAX_CORNERS_OF_SIDE
       }
                         #endif
     }
-                #ifdef __THREEDIM__
+                #ifdef UG_DIM_3
   else if (corners[co]<(coe+eoe+soe))
   {
     /* side mid */
@@ -1468,8 +1469,8 @@ static INT IsOnFatherSide (int tag, int nsco, SHORT sco[], SHORT *nb)
 
     RETURN VALUE:
     INT
-   .n   YES: son sides are mathing
-   .n   NO:  son sides are not mathing
+   .n   YES: son sides are matching
+   .n   NO:  son sides are not matching
    doctext_disabled*/
 /****************************************************************************/
 
@@ -1613,13 +1614,11 @@ static void HRule2Mrule (const HRULE *hr, MGIO_RR_RULE *mr)
       }
   }
 
-        #ifdef __THREEDIM__
+        #ifdef UG_DIM_3
   /* 2D: not even in rm */
   /* son path */
   FillSonPaths(mr);
         #endif
-
-  return;
 }
 
 /****************************************************************************/
@@ -1666,7 +1665,6 @@ static void URule2Mrule (const URULE *ur, MGIO_RR_RULE *mr)
       sonData->nb[k] = ur->sons[j].nb[k];
     sonData->path = ur->sons[j].path;
   }
-  return;
 }
 
 static void WriteDebugInfo (void)
@@ -1697,8 +1695,6 @@ static void WriteDebugInfo (void)
              global.nelem_not_inspected[tag]);
 
   PrintDebug("------------------------------------------------------\n");
-
-  return;
 }
 
 INT NS_DIM_PREFIX GetOrderedSons (ELEMENT *theElement, MGIO_RR_RULE *theRule, NODE **NodeContext, ELEMENT **SonList, INT *nmax)
@@ -1930,7 +1926,7 @@ static void CheckMRules (MULTIGRID *mg, INT RefRuleOffset[], MGIO_RR_RULE *mrule
               }
             }
                                                 #ifndef ModelP
-                                                #ifdef __THREEDIM__
+                                                #ifdef UG_DIM_3
             /* check path
                     NOT CONSISTENT in rm since not used (says Stefan, 971219)
                if (s>0)
@@ -2063,7 +2059,7 @@ INT NS_DIM_PREFIX NEW_Write_RefRules (MULTIGRID *mg, INT RefRuleOffset[], INT Ma
   for (tag=0; tag<TAGS; tag++)
     global.maxrule[tag] = UGMAXRULE(tag);
 
-        #if (defined __THREEDIM__) || (defined __DEBUG_ER__)
+        #if (defined UG_DIM_3) || (defined __DEBUG_ER__)
   /* incomplete refrule set: extract non-existing rules that are realized in mg */
   if (ExtractRules(mg))
     REP_ERR_RETURN(1);
@@ -2151,15 +2147,19 @@ INT NS_DIM_PREFIX NEW_Write_RefRules (MULTIGRID *mg, INT RefRuleOffset[], INT Ma
 INT NS_DIM_PREFIX ResetRefineTagsBeyondRuleManager (MULTIGRID *mg)
 {
   ELEMENT *elem;
-  int l,n=0;
+#ifdef Debug
+  int n = 0;
+#endif
 
   /** \todo (HRR 971211): don't include TOPLEVEL (no elem refined there) */
-  for (l=0; l<=TOPLEVEL(mg); l++)
+  for (int l=0; l<=TOPLEVEL(mg); l++)
     for (elem=PFIRSTELEMENT(GRID_ON_LEVEL(mg,l)); elem!=NULL; elem=SUCCE(elem))
       if (BEYOND_UG_RULES(elem))
       {
         SETREFINE(elem,COPY);
+#ifdef Debug
         n++;
+#endif
       }
   PRINTDEBUG(gm,ER_DBG_GENERAL,("ResetRefineTags: done (for %d elements)\n",n));
 
