@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 /****************************************************************************/
@@ -70,11 +72,11 @@ USING_UG_NAMESPACE
 /*                                                                          */
 /****************************************************************************/
 
-#ifdef __TWODIM__
+#ifdef UG_DIM_2
 const DOUBLE NS_DIM_PREFIX unit_vec[DIM][DIM]={{1,0},{0,1}};
 #endif
 
-#ifdef __THREEDIM__
+#ifdef UG_DIM_3
 const DOUBLE NS_DIM_PREFIX unit_vec[DIM][DIM]={{1,0,0},{0,1,0},{0,0,1}};
 #endif
 
@@ -375,7 +377,7 @@ INT NS_DIM_PREFIX V3_Normalize (DOUBLE *a)
    RETURN VALUE:
    INT
    .n    0 if o.k.
-   .n    1 if error occured.
+   .n    1 if error occurred.
    D*/
 /****************************************************************************/
 
@@ -476,7 +478,7 @@ DOUBLE NS_DIM_PREFIX GeneralElementVolume (INT tag, DOUBLE *x_co[])
 {
   switch (tag)
   {
-#               ifdef __TWODIM__
+#               ifdef UG_DIM_2
   case TRIANGLE :
     return(c_tarea (x_co[0],x_co[1],x_co[2]));
 
@@ -484,7 +486,7 @@ DOUBLE NS_DIM_PREFIX GeneralElementVolume (INT tag, DOUBLE *x_co[])
     return(c_qarea (x_co[0],x_co[1],x_co[2],x_co[3]));
 #               endif
 
-#               ifdef __THREEDIM__
+#               ifdef UG_DIM_3
   case TETRAHEDRON :
     return(V_te(x_co[0],x_co[1],x_co[2],x_co[3]));
 
