@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightInfo: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 /*! \file evm.h
  * \ingroup gm
  */
@@ -195,7 +197,7 @@ START_UGDIM_NAMESPACE
 /*                                                                          */
 /****************************************************************************/
 
-#ifdef __TWODIM__
+#ifdef UG_DIM_2
 
 #define V_BDIM_COPY(A,C)                        V1_COPY(A,C)
 
@@ -216,7 +218,7 @@ START_UGDIM_NAMESPACE
 
 #endif
 
-#ifdef __THREEDIM__
+#ifdef UG_DIM_3
 
 #define V_BDIM_COPY(A,C)                        V2_COPY(A,C)
 
