@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 /****************************************************************************/
 /*                                                                          */
 /* File:      gmcheck.c                                                     */
@@ -70,22 +72,6 @@
 USING_UG_NAMESPACES
 using namespace PPIF;
 
-/****************************************************************************/
-/*                                                                          */
-/* defines in the following order                                           */
-/*                                                                          */
-/* compile time constants defining static data size (i.e. arrays)           */
-/* other constants                                                          */
-/* macros                                                                   */
-/*                                                                          */
-/****************************************************************************/
-
-#define RESOLUTION       20     /* resolution for creating boundary midnode */
-#define SMALL1 0.001
-
-#define ORDERRES                1e-3    /* resolution for OrderNodesInGrid			*/
-#define LINKTABLESIZE   32              /* max number of inks per node for ordering	*/
-
 /****************************************************************************/
 /*                                                                          */
 /* data structures used in this source file (exported data structures are   */
@@ -271,7 +257,7 @@ static INT CheckVertex (ELEMENT *theElement, NODE* theNode, VERTEX *theVertex)
     }
     break;
 
-                #ifdef __THREEDIM__
+                #ifdef UG_DIM_3
   case (SIDE_NODE) :
     if (theFather == NULL)
     {
@@ -342,13 +328,6 @@ static INT CheckNode (ELEMENT *theElement, NODE* theNode, INT i)
     return(nerrors++);
   }
 
-  if (NVECTOR(theNode)!=NULL && VOBJECT(NVECTOR(theNode)) == NULL)
-  {
-    UserWriteF(" node=" ID_FMTX " has vector" ID_FMTX "  with VOBJ=NULL\n",
-               ID_PRTX(theNode),ID_PRTX(NVECTOR(theNode)));
-    return(nerrors++);
-  }
-
   switch (NTYPE(theNode))
   {
   case (LEVEL_0_NODE) :
@@ -530,7 +509,7 @@ static INT CheckEdge (ELEMENT *theElement, EDGE* theEdge, INT i)
 
   /** \todo Commented out because it uses GetElemLink, which does not exist */
 #if 0
-#       if defined(__TWODIM__)
+#       if defined(UG_DIM_2)
   {
     int elemlink,no_of_elem,No_Of_Elem;
     NODE *n0,*n1;
@@ -658,15 +637,13 @@ static INT CheckEdge (ELEMENT *theElement, EDGE* theEdge, INT i)
 #ifdef ModelP
 int EdgeHasTMasterCopy (DDD::DDDContext& context, ELEMENT *e, int i)
 {
-  int nmaster,nborder,nall;
-  EDGE *edge;
-
-  edge = GetEdge(CORNER_OF_EDGE_PTR(e,i,0),CORNER_OF_EDGE_PTR(e,i,1));
+  EDGE* edge = GetEdge(CORNER_OF_EDGE_PTR(e,i,0),CORNER_OF_EDGE_PTR(e,i,1));
   assert(edge != NULL);
 
-  nmaster = CheckProcListCons(PROCLIST(context, edge),PrioMaster);
-  nborder = CheckProcListCons(PROCLIST(context, edge),PrioBorder);
-  nall = nmaster + nborder;
+  const auto& proclist = DDD_InfoProcListRange(context, PARHDR(edge));
+  const int nmaster = CheckProcListCons(proclist, PrioMaster);
+  const int nborder = CheckProcListCons(proclist, PrioBorder);
+  const int nall = nmaster + nborder;
   if (0)
     assert(nall==1 || nall==2);
 
@@ -691,7 +668,7 @@ static INT CheckElement (GRID *theGrid, ELEMENT *theElement, INT *SideError, INT
   ELEMENT *SonList[MAX_SONS];
   VERTEX  *theVertex,*Vertices[MAX_CORNERS_OF_ELEM];
 
-#if defined(ModelP) && defined(__TWODIM__)
+#if defined(ModelP) && defined(UG_DIM_2)
   auto& dddContext = theGrid->dddContext();
 #endif
 
@@ -782,9 +759,9 @@ static INT CheckElement (GRID *theGrid, ELEMENT *theElement, INT *SideError, INT
         if (OBJT(theElement) == BEOBJ)
           if (SIDE_ON_BND(theElement,i))
           {
-            INT err,id,nbid,id_nb,nbid_nb,part;
+            INT err,id,nbid,id_nb,nbid_nb;
 
-            err = BNDS_BndSDesc(ELEM_BNDS(theElement,i),&id,&nbid,&part);
+            err = BNDS_BndSDesc(ELEM_BNDS(theElement,i),&id,&nbid);
             if (err)
             {
               bserror |= (1<<i);
@@ -817,7 +794,7 @@ static INT CheckElement (GRID *theGrid, ELEMENT *theElement, INT *SideError, INT
               }
               else
               {
-                if (BNDS_BndSDesc(ELEM_BNDS(NbElement,j),&id_nb,&nbid_nb,&part))
+                if (BNDS_BndSDesc(ELEM_BNDS(NbElement,j),&id_nb,&nbid_nb))
                 {
                   UserWriteF("nb=" EID_FMTX " ERROR BNDS_BndSDesc(%d) returned id=%d nbid=%d\n",
                              EID_PRTX(NbElement),j,id,nbid);
@@ -895,7 +872,7 @@ static INT CheckElement (GRID *theGrid, ELEMENT *theElement, INT *SideError, INT
         if (OBJT(theElement) == IEOBJ)
                                 #ifdef ModelP
           if (EMASTER(theElement))
-                                #if defined(__TWODIM__)
+                                #if defined(UG_DIM_2)
             if (hghost_overlap!=0.0 || EdgeHasTMasterCopy(dddContext, theElement,i)==0)
                                 #endif
                                 #endif
@@ -907,7 +884,7 @@ static INT CheckElement (GRID *theGrid, ELEMENT *theElement, INT *SideError, INT
         {
                                   #ifdef ModelP
           if (EMASTER(theElement))
-                                  #if defined(__TWODIM__)
+                                  #if defined(UG_DIM_2)
             if (hghost_overlap!=0.0 || EdgeHasTMasterCopy(dddContext, theElement,i)==0)
                                   #endif
                                   #endif
@@ -927,7 +904,7 @@ static INT CheckElement (GRID *theGrid, ELEMENT *theElement, INT *SideError, INT
         else if (ECLASS(theElement)!=YELLOW_CLASS)
                                         #ifdef ModelP
           if (EMASTER(theElement))
-                                    #if defined(__TWODIM__)
+                                    #if defined(UG_DIM_2)
             if (hghost_overlap!=0.0 || EdgeHasTMasterCopy(dddContext, theElement,i)==0)
                                         #endif
                                         #endif
@@ -1130,7 +1107,7 @@ static INT CheckElement (GRID *theGrid, ELEMENT *theElement, INT *SideError, INT
   return (0);
 }
 
-#if defined(__TWODIM__) || defined(ModelP)
+#if defined(UG_DIM_2) || defined(ModelP)
 
 INT CheckSubdomains (MULTIGRID *theMG)
 {
@@ -1264,6 +1241,8 @@ static INT CheckElementSubdomains (GRID *theGrid, ELEMENT *theElement, INT *Node
   }
   else if (EFATHER(theElement)!=NULL)
   {
+    theFather = EFATHER(theElement);
+
     /* extended check on higher levels */
     for (i=0; i<EDGES_OF_ELEM(theElement); i++)
     {
@@ -1818,7 +1797,7 @@ INT NS_DIM_PREFIX CheckLists (GRID *theGrid)
 
    PARAMETERS:
    .  theGrid - grid to check
-   .  checkgeom - check geomtry
+   .  checkgeom - check geometry
    .  checkalgebra - check algebra
    .  checklists - checklists
    .  checkif - check the processor interfaces
@@ -1829,7 +1808,7 @@ INT NS_DIM_PREFIX CheckLists (GRID *theGrid)
    RETURN VALUE:
    INT
    .n   GM_OK if ok
-   .n   GM_ERROR if an error occured.
+   .n   GM_ERROR if an error occurred.
    D*/
 /****************************************************************************/
 
