@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 /****************************************************************************/
@@ -39,7 +41,6 @@
 
 /* gm module */
 #include "gm.h"
-#include "enrol.h"
 #include "algebra.h"
 #include "cw.h"
 #include "ugm.h"
@@ -63,7 +64,7 @@ USING_UGDIM_NAMESPACE
 
 /****************************************************************************/
 /*
-   InitGm - Call the inits for the grid manger module
+   InitGm - Call the inits for the grid manager module
 
    SYNOPSIS:
    INT InitGm ();
@@ -72,12 +73,12 @@ USING_UGDIM_NAMESPACE
    .  void
 
    DESCRIPTION:
-   This function calls the inits for the grid manger module.
+   This function calls the inits for the grid manager module.
 
    RETURN VALUE:
    INT
    .n     0 if ok
-   .n     1 if some error occured.
+   .n     1 if some error occurred.
  */
 /****************************************************************************/
 
@@ -99,21 +100,6 @@ INT NS_DIM_PREFIX InitGm ()
     return (err);
   }
 
-
-  /* enrol.c */
-  if ((err=InitEnrol())!=0)
-  {
-    SetHiWrd(err,__LINE__);
-    return (err);
-  }
-
-  /* algebra.c */
-  if ((err=InitAlgebra())!=0)
-  {
-    SetHiWrd(err,__LINE__);
-    return (err);
-  }
-
   /* ugm.c */
   if ((err=InitUGManager())!=0)
   {
