@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 /****************************************************************************/
 /*                                                                          */
 /* File:      shapes.c                                                      */
@@ -31,6 +33,8 @@
 #include <cassert>
 #include <cstddef>
 
+#include <algorithm>
+
 #include <dune/uggrid/low/architecture.h>
 #include <dune/uggrid/low/misc.h>
 #include <dune/uggrid/low/ugtypes.h>
@@ -75,11 +79,11 @@ USING_UG_NAMESPACE
 /****************************************************************************/
 
 /* local midpoints */
-#ifdef __TWODIM__
+#ifdef UG_DIM_2
 static DOUBLE_VECTOR_2D LMP_Triangle            = {0.333333333333333333, 0.333333333333333333};
 static DOUBLE_VECTOR_2D LMP_Quadrilateral       = {0.5, 0.5};
 #endif
-#ifdef __THREEDIM__
+#ifdef UG_DIM_3
 static DOUBLE_VECTOR_3D LMP_Tetrahedron         = {0.25, 0.25, 0.25};
 static DOUBLE_VECTOR_3D LMP_Pyramid             = {0.5, 0.5, 0.33333333333333333};
 static DOUBLE_VECTOR_3D LMP_Prism               = {0.333333333333333333,
@@ -108,7 +112,7 @@ static DOUBLE_VECTOR_3D LMP_Hexahedron          = {0.5, 0.5, 0.5};
 
 DOUBLE * NS_DIM_PREFIX LMP (INT n)
 {
-#ifdef __TWODIM__
+#ifdef UG_DIM_2
   switch (n)
   {
   case 3 : return (LMP_Triangle);
@@ -116,7 +120,7 @@ DOUBLE * NS_DIM_PREFIX LMP (INT n)
   }
 #endif
 
-#ifdef __THREEDIM__
+#ifdef UG_DIM_3
   switch (n)
   {
   case 4 : return (LMP_Tetrahedron);
@@ -141,7 +145,7 @@ DOUBLE * NS_DIM_PREFIX LMP (INT n)
 
    \return <ul>
    <li>   0 if ok </li>
-   <li>   1 if error occured. </li>
+   <li>   1 if error occurred. </li>
    </ul>
  */
 /****************************************************************************/
@@ -195,12 +199,12 @@ INT NS_DIM_PREFIX UG_GlobalToLocal (INT n, const DOUBLE **Corners,
 
    \return <ul>
    <li>   0 if ok </li>
-   <li>   1 if error occured. </li>
+   <li>   1 if error occurred. </li>
    </ul>
  */
 /****************************************************************************/
 
-#ifdef __THREEDIM__
+#ifdef UG_DIM_3
 INT NS_DIM_PREFIX TetraSideNormals (ELEMENT *theElement, DOUBLE **theCorners, DOUBLE_VECTOR theNormals[MAX_SIDES_OF_ELEM])
 {
   ELEMENT e;
@@ -239,12 +243,12 @@ INT NS_DIM_PREFIX TetraSideNormals (ELEMENT *theElement, DOUBLE **theCorners, DO
 
    \return <ul>
    <li>   0 if ok </li>
-   <li>   1 if error occured. </li>
+   <li>   1 if error occurred. </li>
    </ul>
  */
 /****************************************************************************/
 
-#ifdef __THREEDIM__
+#ifdef UG_DIM_3
 INT NS_DIM_PREFIX TetMaxSideAngle (ELEMENT *theElement, const DOUBLE **theCorners, DOUBLE *MaxAngle)
 {
   DOUBLE_VECTOR theNormal[MAX_SIDES_OF_ELEM];
@@ -256,9 +260,9 @@ INT NS_DIM_PREFIX TetMaxSideAngle (ELEMENT *theElement, const DOUBLE **theCorner
   for (i=0; i<EDGES_OF_ELEM(theElement); i++)
   {
     V3_SCALAR_PRODUCT(theNormal[SIDE_WITH_EDGE(theElement,i,0)],theNormal[SIDE_WITH_EDGE(theElement,i,1)],help)
-    max = MAX(help,max);
+    max = std::max(help,max);
   }
-  max = MIN(max,1.0);
+  max = std::min(max,1.0);
   *MaxAngle = 180.0/PI*acos(-max);
 
   return (0);
@@ -277,12 +281,12 @@ INT NS_DIM_PREFIX TetMaxSideAngle (ELEMENT *theElement, const DOUBLE **theCorner
 
    \return <ul>
    <li>   0 if ok </li>
-   <li>   1 if error occured. </li>
+   <li>   1 if error occurred. </li>
    </ul>
  */
 /****************************************************************************/
 
-#ifdef __THREEDIM__
+#ifdef UG_DIM_3
 INT NS_DIM_PREFIX TetAngleAndLength (ELEMENT *theElement, const DOUBLE **theCorners, DOUBLE *Angle, DOUBLE *Length)
 {
   DOUBLE_VECTOR theNormals[MAX_SIDES_OF_ELEM],theEdge[MAX_EDGES_OF_ELEM];
@@ -308,8 +312,7 @@ INT NS_DIM_PREFIX TetAngleAndLength (ELEMENT *theElement, const DOUBLE **theCorn
   for (j=0; j<EDGES_OF_ELEM(theElement); j++)
   {
     V3_SCALAR_PRODUCT(theNormals[SIDE_WITH_EDGE(theElement,j,0)],theNormals[SIDE_WITH_EDGE(theElement,j,1)],Angle[j])
-    Angle[j] = MAX(Angle[j],-1.0);
-    Angle[j] = MIN(Angle[j], 1.0);
+    Angle[j] = std::clamp(Angle[j], -1.0, 1.0);
     Angle[j] = (DOUBLE)acos((double)Angle[j]);
   }
 
