@@ -1,5 +1,7 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
+// SPDX-FileCopyrightInfo: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 /*! \file ugm.h
  * \ingroup gm
  */
@@ -86,7 +88,7 @@ INT              ReleaseOBJT                    (GM_OBJECTS);
 /* create basic objects */
 /** \todo Commented out because no definitions exist for these declarations
 
-   #if defined(__TWODIM__)
+   #if defined(UG_DIM_2)
    int      GetElemLink (NODE *from, NODE *to, ELEMENT *theElement);
    ELEMENT *NbElem     (const ELEMENT *theElement, int i);
    void     Set_NbElem (ELEMENT *theElement, int i, ELEMENT *Neighbor);
@@ -104,15 +106,12 @@ INT         CreateSonElementSide    (GRID *theGrid, ELEMENT *theElement,
 GRID            *CreateNewLevel                 (MULTIGRID *theMG);
 
 /* dispose basic objects */
-INT              DisposeElement                 (GRID *theGrid, ELEMENT *theElement, INT dispose_connections);
+INT              DisposeElement                 (GRID *theGrid, ELEMENT *theElement);
 INT              DisposeTopLevel                (MULTIGRID *theMG);
 INT              DisposeNode                    (GRID *theGrid, NODE *theNode);
 
 /* miscellaneous */
 INT              FindNeighborElement    (const ELEMENT *theElement, INT Side, ELEMENT **theNeighbor, INT *NeighborSide);
-bool             PointInElement                 (const DOUBLE*, const ELEMENT *theElement);
-INT          PointOnSide            (const DOUBLE *global, const ELEMENT *theElement, INT side);
-DOUBLE       DistanceFromSide       (const DOUBLE *global, const ELEMENT *theElement, INT side);
 INT             CheckOrientation                (INT n, VERTEX **vertices);
 INT             CheckOrientationInGrid  (GRID *theGrid);
 
@@ -121,7 +120,7 @@ NODE            *CreateMidNode                  (GRID *theGrid, ELEMENT *theElem
 NODE            *GetCenterNode                  (const ELEMENT *theElement);
 NODE        *CreateCenterNode       (GRID *theGrid, ELEMENT *theElement, VERTEX *theVertex);
 
-#ifdef __THREEDIM__
+#ifdef UG_DIM_3
 NODE            *CreateSideNode                 (GRID *theGrid, ELEMENT *theElement, VERTEX *theVertex, INT side);
 NODE            *GetSideNode                    (const ELEMENT *theElement, INT side);
 #endif
