@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 /****************************************************************************/
@@ -175,8 +177,8 @@ static char nexttoken[NAMESIZE];        /* must be global for lastnameHnd ! */
    \param name - name to be found (from current structure directory)
    \param lastnameHnd - if not NULL it is set to a pointer to the last name
 
-   This function searchs (starting from the current structure directory)
-   for the structure directory given by name and returns its adress.
+   This function searches (starting from the current structure directory)
+   for the structure directory given by name and returns its address.
    It does not change the current structure directory! If 'lastnameHnd!=NULL'
    it also sets '*lastNameHnd' to be a pointer to the last name of the directory.
 
@@ -382,7 +384,7 @@ char * NS_PREFIX GetStringVar (const char *name)
 
    \return <ul>
    <li> 0 if ok </li>
-   <li> 1 if error occured </li>
+   <li> 1 if error occurred </li>
    </ul>
  */
 /****************************************************************************/
@@ -403,7 +405,7 @@ INT NS_PREFIX GetStringValue (const char *name, double *value)
 
    \return <ul>
    <li> 0 if ok </li>
-   <li> 1 if error occured </li>
+   <li> 1 if error occurred </li>
    </ul>
  */
 /****************************************************************************/
@@ -433,7 +435,7 @@ INT NS_PREFIX GetStringValueDouble (const char *name, double *value)
 
    \return <ul>
    <li> 0 if ok </li>
-   <li> 1 if error occured </li>
+   <li> 1 if error occurred </li>
    </ul>
  */
 /****************************************************************************/
@@ -478,7 +480,7 @@ ENVDIR * NS_PREFIX GetCurrentStructDir ()
 
    \return
    <li>  0 if ok </li>
-   <li>  1 if error occured. </li>
+   <li>  1 if error occurred. </li>
  */
 /****************************************************************************/
 
@@ -598,7 +600,7 @@ ENVITEM * NS_PREFIX MakeStructItem (ENVDIR *where, const char *name, INT type, I
 
    \return <ul>
    <li>  0 if ok </li>
-   <li>  1 if error occured </li>
+   <li>  1 if error occurred </li>
    </ul>
  */
 /****************************************************************************/
@@ -659,7 +661,7 @@ INT NS_PREFIX DeleteStruct (const char *name)
 }
 
 /****************************************************************************/
-/** \brief Remove a string variable fro the environment tree
+/** \brief Remove a string variable from the environment tree
 
    \param homeDir - theVar is located in this directory
    \param theVar - string var to remove
@@ -982,7 +984,7 @@ INT NS_PREFIX CheckIfInStructPath (const ENVDIR *theDir)
 
    \return <ul>
    <li>  0 if ok </li>
-   <li>  1 if error occured </li>
+   <li>  1 if error occurred </li>
    </ul>
  */
 /****************************************************************************/
