@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 /****************************************************************************/
@@ -502,6 +504,24 @@ void DisposeCouplingList (DDD::DDDContext& context, COUPLING *cpl)
 }
 
 
+/*
+ * DDD_InfoProcListRange
+ */
+
+DDD_InfoProcListRange::DDD_InfoProcListRange(DDDContext& context, const DDD_HDR hdr, bool includeDummy) noexcept
+  : includeDummy_(includeDummy)
+{
+  dummy_._proc = context.me();
+  dummy_.prio = OBJ_PRIO(hdr);
+
+  const auto objIndex = OBJ_INDEX(hdr);
+  if (objIndex < context.couplingContext().nCpls) {
+    dummy_._next = IdxCplList(context, objIndex);
+  }
+  else {
+    dummy_._next = nullptr;
+  }
+}
 
 /****************************************************************************/
 /*                                                                          */
