@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 /****************************************************************************/
@@ -198,7 +200,6 @@ static GRID *GetGridOnDemand (MULTIGRID *mg, int level)
 /*				 TypeEdge													*/
 /*																			*/
 /*			DDD data objects:												*/
-/*				TypeMatrix,                                                                                             */
 /*				2-Dim:														*/
 /*				TypeEdge													*/
 /*																			*/
@@ -219,7 +220,7 @@ static void VectorUpdate (DDD::DDDContext& context, DDD_OBJ obj)
   VECTOR  *pv                     = (VECTOR *)obj;
   INT level           = ATTR_TO_GLEVEL(DDD_InfoAttr(PARHDR(pv)));
   GRID    *theGrid        = GRID_ON_LEVEL(ddd_ctrl(context).currMG,level);
-  INT prio            = PRIO(pv);
+  const DDD_PRIO prio = PRIO(pv);
 
   PRINTDEBUG(dddif,1,(PFMT " VectorUpdate(): v=" VINDEX_FMTX
                       " VEOBJ=%d\n",me,VINDEX_PRTX(pv),OBJT(pv)))
@@ -232,13 +233,8 @@ static void VectorUpdate (DDD::DDDContext& context, DDD_OBJ obj)
 
 static void VectorXferCopy(DDD::DDDContext& context, DDD_OBJ obj, DDD_PROC proc, DDD_PRIO prio)
 {
-  INT nmat    = 0;
-  MATRIX  *mat;
   VECTOR  *pv             = (VECTOR *)obj;
   INT level           = ATTR_TO_GLEVEL(DDD_InfoAttr(PARHDR(pv)));
-  /* TODO: define this static global                    */
-  /* TODO: take size as maximum of possible connections */
-  size_t sizeArray[256];
   INT flag;
 
   PRINTDEBUG(dddif,1,(PFMT " VectorXferCopy(): v=" VINDEX_FMTX " proc=%d "
@@ -253,17 +249,6 @@ static void VectorXferCopy(DDD::DDDContext& context, DDD_OBJ obj, DDD_PROC proc,
         #endif
 #endif
 
-  if (flag) {
-    if (DDD_XferWithAddData(context)) {
-      for(mat=VSTART(pv); mat!=NULL; mat=MNEXT(mat)) {
-        ASSERT(nmat<256);
-        sizeArray[nmat++] = UG_MSIZE(mat);
-      }
-      PRINTDEBUG(dddif,2,(PFMT " VectorXferCopy(): v=" VINDEX_FMTX
-                          " AddData nmat=%d\n",me,VINDEX_PRTX(pv),nmat))
-      DDD_XferAddDataX(context, nmat, ddd_ctrl(context).TypeMatrix,sizeArray);
-    }
-  }
   /*
           else
           {
@@ -279,369 +264,13 @@ static void VectorXferCopy(DDD::DDDContext& context, DDD_OBJ obj, DDD_PROC proc,
    */
 }
 
-static void VectorGatherMatX (DDD::DDDContext&, DDD_OBJ obj, int cnt, DDD_TYPE type_id, char **Data)
-{
-  VECTOR  *vec = (VECTOR *)obj;
-  MATRIX  *mat;
-  INT nmat = 0;
-
-  PRINTDEBUG(dddif,3,(PFMT " VectorGatherMatX(): v=" VINDEX_FMTX
-                      " VOBJID=%d cnt=%d type=%d veobj=%d vtype=%d\n",
-                      me,VINDEX_PRTX(vec),ID(VOBJECT(vec)),cnt,type_id,
-                      OBJT(vec),VTYPE(vec)))
-
-  if (cnt<=0) return;
-
-  for (mat=VSTART((VECTOR *) vec); mat!=NULL; mat=MNEXT(mat))
-  {
-    int Size;
-
-    IFDEBUG(dddif,0)
-    if (cnt<nmat+1)
-    {
-      PRINTDEBUG(dddif,0,(PFMT " VectorGatherMatX(): v=" VINDEX_FMTX
-                          " cnt=%d nmat=%d type=%d veobj=%d\n",
-                          me,VINDEX_PRTX(vec),cnt,nmat,type_id,OBJT(vec)))
-      assert(0);
-    }
-    ENDDEBUG
-
-      Size = UG_MSIZE(mat);
-    memcpy(Data[nmat],mat,Size);
-
-    PRINTDEBUG(dddif,3,(PFMT " VectorGatherMatX(): v=" VINDEX_FMTX
-                        " mat=%x Size=%d vectoID=" VINDEX_FMTX "\n",
-                        me,VINDEX_PRTX(vec),mat,Size,VINDEX_PRTX(MDEST(mat))))
-
-    nmat++;
-  }
-}
-
-
-static void VectorScatterConnX (DDD::DDDContext& context, DDD_OBJ obj, int cnt, DDD_TYPE type_id, char **Data, int newness)
-{
-  VECTOR          *vec            = (VECTOR *)obj;
-  CONNECTION      *first          = NULL,
-  *last           = NULL;
-  INT level           = ATTR_TO_GLEVEL(DDD_InfoAttr(PARHDR(vec)));
-  GRID            *theGrid        = GRID_ON_LEVEL(ddd_ctrl(context).currMG,level);
-  INT prio            = PRIO(vec);
-  INT i;
-  INT nconn           = 0;
-  INT newconn         = 0;
-
-  PRINTDEBUG(dddif,3,(PFMT " VectorScatterConnX(): v=" VINDEX_FMTX
-                      " cnt=%d type=%d veobj=%d vtype=%d\n",\
-                      me,VINDEX_PRTX(vec),cnt,type_id,OBJT(vec),VTYPE(vec)))
-
-#if ! defined __OVERLAP2__
-  if (GHOSTPRIO(prio))
-  {
-    PRINTDEBUG(dddif,4,(PFMT " VectorScatterConnX(): v=" VINDEX_FMTX
-                        " USELESS since ghost vector\n",
-                        me,VINDEX_PRTX(vec)))
-    return;
-  }
-#endif
-
-  if (cnt<=0) return;
-
-  for (i=0; i<cnt; i++)
-  {
-    MATRIX *mcopy = (MATRIX *)Data[i];
-
-    /* reset MNEXT */
-    MNEXT(mcopy) = NULL;
-
-    if (MDEST(mcopy)==NULL)
-    {
-      /* destination vector is not on this processor  */
-      /* -> matrix entry is useless, throw away       */
-      PRINTDEBUG(dddif,4,(PFMT " VectorScatterConnX(): v=" VINDEX_FMTX
-                          " mat=%x Size=%d, USELESS no dest vector \n",
-                          me,VINDEX_PRTX(vec),mcopy,UG_MSIZE(mcopy)))
-      continue;
-    }
-
-#if ! defined __OVERLAP2__
-    if (GHOST(MDEST(mcopy)))
-    {
-      /* destination vector has only prio Ghost on this processor */
-      /* -> matrix entry is useless, throw away                     */
-      PRINTDEBUG(dddif,4,(PFMT " VectorScatterConnX(): v=" VINDEX_FMTX
-                          " mat=%x Size=%d, USELESS dest vect is ghost\n",
-                          me,VINDEX_PRTX(vec),mcopy,UG_MSIZE(mcopy)))
-      continue;
-    }
-#endif
-
-    {
-      MATRIX *m,*mat=NULL;
-
-      /* does matrix entry already exist? */
-      /* TODO not nice, linear search, change this! */
-      for (m=VSTART((VECTOR *)vec);
-           m!=NULL && (mat==NULL);
-           m=MNEXT(m))
-      {
-        if (MDEST(m)==MDEST(mcopy)) mat=m;
-      }
-
-      /* matrix entry is really new */
-      if (mat == NULL)
-      {
-        /* handle diagonal entry */
-        if (MDIAG(mcopy))
-        {
-          /* matrix diagonal entry, no other vector is involved */
-          CONNECTION *conn = (CONNECTION *)
-                             GetMemoryForObject(ddd_ctrl(context).currMG,UG_MSIZE(mcopy),MAOBJ);
-
-          nconn++; newconn++;
-
-          if (conn==NULL)
-          {
-            UserWriteF("%2d:  VectorScatterConnX(): can't get mem "
-                       "for conn=%x\n",conn);
-            return;
-          }
-
-          PRINTDEBUG(dddif,4,(PFMT " VectorScatterConnX(): v="
-                              VINDEX_FMTX " conn=%x Size=%d, DIAG\n",
-                              me,VINDEX_PRTX(vec),conn,UG_MSIZE(mcopy)))
-
-
-          /* TODO: define clearly
-             memcpy(conn,mcopy,UG_MSIZE(mcopy)); */
-          memset(conn,0,UG_MSIZE(mcopy));
-          memcpy(conn,mcopy,sizeof(MATRIX)-sizeof(DOUBLE));
-
-          if (first==NULL) first = conn;
-          else MNEXT(last) = conn;
-          last = conn;
-        }
-        /* handle off-diagonal entry */
-        else
-        {
-          /* matrix off-diagonal entry, another vector is involved */
-          VECTOR *other = MDEST(mcopy);
-          MATRIX *m, *back=NULL, *newm;
-
-          /* does connection already exist for other vec? */
-          /* TODO not nice, linear search, change this! */
-
-          for (m=VSTART((VECTOR *)other);
-               m!=NULL && back==NULL;
-               m=MNEXT(m))
-          {
-            if (MDEST(m)==vec) back=m;
-          }
-
-          /* no backward entry, create connection */
-          if (back==NULL)
-          {
-            MATRIX *otherm;
-            CONNECTION *conn = (CONNECTION *)
-                               GetMemoryForObject(ddd_ctrl(context).currMG,2*UG_MSIZE(mcopy),MAOBJ);
-
-            nconn++; newconn++;
-
-            if (conn==NULL)
-            {
-              UserWriteF("%2d:  VectorScatterConnX(): can't get "
-                         "mem for mat=%x\n",mcopy);
-              return;
-            }
-
-
-            if (MOFFSET(mcopy))
-            {
-              newm =         (MATRIX *) ((char *)conn+UG_MSIZE(mcopy));
-              otherm = (MATRIX *) conn;
-
-              PRINTDEBUG(dddif,4,(PFMT " VectorScatterConnX(): v="
-                                  VINDEX_FMTX " conn=%x newm=%x Size=%d vectoID="
-                                  VINDEX_FMTX " GETMEM\n",
-                                  me,VINDEX_PRTX(vec),conn,newm, UG_MSIZE(mcopy),
-                                  VINDEX_PRTX(MDEST(mcopy))))
-            }
-            else
-            {
-              newm = (MATRIX *) conn;
-              otherm = (MATRIX *) ((char *)conn+UG_MSIZE(mcopy));
-
-              PRINTDEBUG(dddif,4,(PFMT " VectorScatterConnX(): v="
-                                  VINDEX_FMTX " conn=%x newm=%x Size=%d vectoID="
-                                  VINDEX_FMTX " GETMEM\n",
-                                  me,VINDEX_PRTX(vec),conn,newm, UG_MSIZE(mcopy),
-                                  VINDEX_PRTX(MDEST(mcopy))))
-            }
-
-            MDEST(otherm) = NULL;
-          }
-          /* backward entry found, use existing connection */
-          else
-          {
-            nconn++;
-            /*
-               newm = MADJ(back);
-             */
-            if (MOFFSET(back))
-            {
-              newm = (MATRIX *) ((char *)back-UG_MSIZE(mcopy));
-              SETMOFFSET(mcopy,0);
-            }
-            else
-            {
-              newm = (MATRIX *) ((char *)back+UG_MSIZE(mcopy));
-              SETMOFFSET(mcopy,1);
-            }
-
-            PRINTDEBUG(dddif,4,(PFMT " VectorScatterConnX(): v="
-                                VINDEX_FMTX " back=%x newm=%x Size=%d vectoID="
-                                VINDEX_FMTX " REUSE\n",
-                                me,VINDEX_PRTX(vec),back,newm,UG_MSIZE(mcopy),
-                                VINDEX_PRTX(MDEST(mcopy))))
-          }
-
-          /* TODO: define clearly
-             memcpy(newm,mcopy,UG_MSIZE(mcopy)); */
-          memset(newm,0,UG_MSIZE(mcopy));
-          memcpy(newm,mcopy,sizeof(MATRIX)-sizeof(DOUBLE));
-
-          if (first==NULL) first = newm;
-          else MNEXT(last) = newm;
-          last = newm;
-        }
-      }
-      /* matrix entry does already exist */
-      else
-      {
-        PRINTDEBUG(dddif,4,(PFMT " VectorScatterConnX(): v="
-                            VINDEX_FMTX " mat=%x Size=%d vectoID=" VINDEX_FMTX
-                            " FOUND\n",me,VINDEX_PRTX(vec),mat,UG_MSIZE(mcopy),
-                            VINDEX_PRTX(MDEST(mcopy))))
-      }
-    }
-  }
-
-  /* enter matrix list at the beginning of existing list for this vector */
-  /* ensure diagonal entry being at first position */
-  if (nconn > 0)
-  {
-    if (VSTART(vec)!=NULL)
-    {
-      MNEXT(last) = MNEXT(VSTART(vec));
-      MNEXT(VSTART(vec)) = first;
-    }
-    else
-    {
-      MNEXT(last) = NULL;
-      VSTART(vec) = first;
-    }
-
-                #ifdef Debug
-    /*
-                    {
-                    MATRIX *mat;
-            PRINTDEBUG(dddif,4,(PFMT " VectorScatterConnX():  v="
-                    VINDEX_FMTX "new matrices:\n",me,VINDEX_PRTX(vec)));
-                    for (mat=first; mat!=NULL; mat=MNEXT(mat))
-                    {
-                    PRINTDEBUG(dddif,4,(PFMT "     mat=%x dest=" EID_FMTX "\n",me,mat,VINDEX_PRTX(MDEST(mat))));
-                    }
-                    }
-     */
-                #endif
-  }
-
-#ifdef Debug
-  {
-    MATRIX *mat=NULL;
-
-    for (mat=VSTART(vec); mat!=NULL; mat=MNEXT(mat))
-    {
-      if (MDEST(mat) == MDEST(MADJ(mat)))
-      {
-        if (MDIAG(mat)) continue;
-
-        if (!MDIAG(mat))
-          PRINTDEBUG(dddif,1,(PFMT " VectorScatterConnX(): NOT DIAGONAL v="
-                              VINDEX_FMTX " conn=%x mat=%x Size=%d vectoID=" VINDEX_FMTX
-                              "\n",me,VINDEX_PRTX(vec),MMYCON(mat),mat,UG_MSIZE(mat),
-                              VINDEX_PRTX(MDEST(mat))));
-      }
-    }
-  }
-#endif
-
-  /* count new connections */
-  NC(theGrid) += newconn;
-}
-
-
-
-static void VectorObjMkCons (DDD::DDDContext& context, DDD_OBJ obj, int newness)
-{
-  VECTOR          *vec            = (VECTOR *) obj;
-  MATRIX          *theMatrix,*Prev,*Next;
-  INT level           = ATTR_TO_GLEVEL(DDD_InfoAttr(PARHDR(vec)));
-  GRID        *theGrid    = GRID_ON_LEVEL(ddd_ctrl(context).currMG,level);
-
-
-  PRINTDEBUG(dddif,2,(PFMT " VectorObjMkCons(): v=" VINDEX_FMTX
-                      " VEOBJ=%d\n",
-                      me,VINDEX_PRTX(vec),OBJT(vec)))
-
-  /*
-          NOTE (TODO): this might be too less. for n2n transfer, connections
-          might be set up consisting of two matrix structures transfered from
-          different procs. this code will NOT handle that case, the connection
-          will be created with the first matrix and destroyed here. When the
-          second message arrives, the second matrix will lead to construction
-          of a second connection, which will also be deleted here. we would
-          need a mkcons after all messages to handle that case. (NIY in ddd 1.6.5)
-
-          THIS case is handeled in newer DDD version (s.l. 970127)!!
-   */
-
-  /* kill inconsistent connections */
-  for (theMatrix = VSTART((VECTOR *)vec);
-       theMatrix!=NULL; theMatrix=Next)
-  {
-    MATRIX *theAdjoint = MADJ(theMatrix);
-
-    Next = MNEXT(theMatrix);
-
-    if (MDEST(theAdjoint) == NULL)
-    {
-      PRINTDEBUG(dddif,4,(PFMT " VectorObjMkCons(): v=" VINDEX_FMTX
-                          " mat=%x vectoID=%d, KILLING incomplete connection\n",
-                          me,VINDEX_PRTX(vec),theMatrix,ID(MDEST(theMatrix))))
-
-      ASSERT(!MDIAG(theMatrix));
-
-      {
-        INT size = ((MDIAG(theMatrix)) ? UG_MSIZE(theMatrix) : 2*UG_MSIZE(theMatrix));
-        PutFreeObject(ddd_ctrl(context).currMG,MMYCON(theMatrix),size,MAOBJ);
-      }
-
-
-      MNEXT(Prev) = Next;
-
-      NC(theGrid)--;
-      continue;
-    }
-    Prev = theMatrix;
-  }
-}
 
 static void VectorPriorityUpdate (DDD::DDDContext& context, DDD_OBJ obj, DDD_PRIO isnew)
 {
   VECTOR  *pv                     = (VECTOR *)obj;
   INT level           = ATTR_TO_GLEVEL(DDD_InfoAttr(PARHDR(pv)));
   GRID    *theGrid        = GRID_ON_LEVEL(ddd_ctrl(context).currMG,level);
-  INT old                     = PRIO(pv);
+  DDD_PRIO old                     = PRIO(pv);
 
   PRINTDEBUG(dddif,2,(PFMT " VectorPriorityUpdate(): v=" VINDEX_FMTX
                       " old=%d new=%d level=%d attr=%d\n",
@@ -665,28 +294,6 @@ static void VectorPriorityUpdate (DDD::DDDContext& context, DDD_OBJ obj, DDD_PRI
     return;
   }
 
-  /* dispose connections for geom levels not for amg levels */
-#if ! defined __OVERLAP2__
-  if (level>=0)
-    if (GHOSTPRIO(isnew))
-    {
-      MATRIX *theMatrix,*next;
-
-      for (theMatrix=VSTART(pv); theMatrix!=NULL;
-           theMatrix = next)
-      {
-        next = MNEXT(theMatrix);
-
-        PRINTDEBUG(dddif,2,(PFMT " VectorPriorityUpdate(): v="
-                            VINDEX_FMTX " old=%d new=%d dispose conn=%x\n",
-                            me,VINDEX_PRTX(pv),old,isnew,MMYCON(theMatrix)))
-
-        if (DisposeConnection(theGrid,MMYCON(theMatrix)))
-          ASSERT(0);
-      }
-    }
-#endif
-
         #ifdef __EXCHANGE_CONNECTIONS__
   IFDEBUG(dddif,1)
   if (isnew == PrioMaster)
@@ -704,8 +311,6 @@ static void VectorPriorityUpdate (DDD::DDDContext& context, DDD_OBJ obj, DDD_PRI
   GRID_UNLINK_VECTOR(theGrid,pv);
 
   GRID_LINK_VECTOR(theGrid,pv,isnew);
-
-  return;
 }
 
 /****************************************************************************/
@@ -832,7 +437,7 @@ static void VertexPriorityUpdate (DDD::DDDContext& context, DDD_OBJ obj, DDD_PRI
   VERTEX      *theVertex                      = (VERTEX *)obj;
   INT level           = LEVEL(theVertex);
   GRID        *theGrid        = GetGridOnDemand(ddd_ctrl(context).currMG,level);
-  INT old                     = VXPRIO(theVertex);
+  DDD_PRIO old = VXPRIO(theVertex);
 
   PRINTDEBUG(dddif,2,(PFMT " VertexPriorityUpdate(): v=" VID_FMTX
                       " old=%d new=%d level=%d\n",me,VID_PRTX(theVertex),old,new_,level))
@@ -857,8 +462,6 @@ static void VertexPriorityUpdate (DDD::DDDContext& context, DDD_OBJ obj, DDD_PRI
   GRID_UNLINK_VERTEX(theGrid,theVertex);
 
   GRID_LINK_VERTEX(theGrid,theVertex,new_);
-
-  return;
 }
 
 /****************************************************************************/
@@ -914,7 +517,7 @@ static void NodeObjMkCons (DDD::DDDContext& context, DDD_OBJ obj, int newness)
 
   /* TODO: this needs to be done here not in NodeUpdate() for 2D,       */
   /* since father would be overwritten by ElemScatterEdge()                     */
-        #ifdef __TWODIM__
+        #ifdef UG_DIM_2
   if (NFATHER(theNode) != NULL)
   {
     switch (NTYPE(theNode))
@@ -935,11 +538,6 @@ static void NodeObjMkCons (DDD::DDDContext& context, DDD_OBJ obj, int newness)
     }
   }
         #endif
-
-  /* set pointer of vector to its node */
-  if (ddd_ctrl(context).nodeData && NVECTOR(theNode))
-    VOBJECT(NVECTOR(theNode)) = (GEOM_OBJECT*)theNode;
-
 }
 
 
@@ -972,7 +570,7 @@ static void NodeUpdate (DDD::DDDContext& context, DDD_OBJ obj)
 
   /* TODO: can this be done in NodeObjMkCons() also	*/
   /* to unify 2 and 3D case							*/
-        #ifdef __THREEDIM__
+        #ifdef UG_DIM_3
   if (NFATHER(theNode) != NULL)
   {
     switch (NTYPE(theNode))
@@ -1011,7 +609,7 @@ static void NodeUpdate (DDD::DDDContext& context, DDD_OBJ obj)
 /*																			*/
 /* Purpose:   initiate dependent copy of data related to a node.	                */
 /*																			*/
-/* Input:	  DDD_OBJ	obj:	the object which is transfered to proc		*/
+/* Input:	  DDD_OBJ	obj:	the object which is transferred to proc		*/
 /*			  int		proc:	destination processor for that object		*/
 /*			  int		prio:	priority of object new local object			*/
 /*																			*/
@@ -1022,7 +620,6 @@ static void NodeUpdate (DDD::DDDContext& context, DDD_OBJ obj)
 static void NodeXferCopy (DDD::DDDContext& context, DDD_OBJ obj, DDD_PROC proc, DDD_PRIO prio)
 {
   NODE    *theNode        = (NODE *)obj;
-  VECTOR  *vec            = NULL;
 
   PRINTDEBUG(dddif,1,(PFMT " NodeXferCopy(): n=" ID_FMTX
                       " proc=%d prio=%d\n",
@@ -1063,22 +660,6 @@ static void NodeXferCopy (DDD::DDDContext& context, DDD_OBJ obj, DDD_PROC proc,
   }
 
   DDD_XferCopyObj(context, PARHDRV(MYVERTEX(theNode)), proc, prio);
-
-  /* copy vector if defined */
-  if (ddd_ctrl(context).nodeData)
-  {
-    vec = NVECTOR(theNode);
-    if (vec != NULL) {
-      INT Size = sizeof(VECTOR)-sizeof(DOUBLE)
-             +FMT_S_VEC_TP(MGFORMAT(ddd_ctrl(context).currMG),VTYPE(vec));
-
-      PRINTDEBUG(dddif,2,(PFMT " NodeXferCopy(): n=" ID_FMTX
-                          " Xfer NODEVEC=" VINDEX_FMTX " size=%d\n",
-                          me,ID_PRTX(theNode),VINDEX_PRTX(vec),Size))
-
-      DDD_XferCopyObjX(context, PARHDR(vec), proc, prio, Size);
-    }
-  }
 }
 
 
@@ -1087,7 +668,7 @@ static void NodePriorityUpdate (DDD::DDDContext& context, DDD_OBJ obj, DDD_PRIO
   NODE    *pn                     = (NODE *)obj;
   INT level           = LEVEL(pn);
   GRID    *theGrid        = GetGridOnDemand(ddd_ctrl(context).currMG,level);
-  INT old                     = PRIO(pn);
+  const DDD_PRIO old = PRIO(pn);
 
   PRINTDEBUG(dddif,2,(PFMT " NodePriorityUpdate(): n=" ID_FMTX " old=%d new=%d "
                       "level=%d\n",me,ID_PRTX(pn),old,new_,level))
@@ -1114,8 +695,6 @@ static void NodePriorityUpdate (DDD::DDDContext& context, DDD_OBJ obj, DDD_PRIO
   /* insert in new list part */
   GRID_UNLINK_NODE(theGrid,pn);
   GRID_LINK_NODE(theGrid,pn,new_);
-
-  return;
 }
 
 DDD_TYPE NS_DIM_PREFIX NFatherObjType(DDD::DDDContext& context, DDD_OBJ obj, DDD_OBJ ref)
@@ -1247,12 +826,9 @@ static void ElementDelete (DDD::DDDContext& context, DDD_OBJ obj)
   INT level           = LEVEL(pe);
   GRID    *theGrid        = GRID_ON_LEVEL(ddd_ctrl(context).currMG,level);
 
-  PRINTDEBUG(dddif,1,(PFMT " ElementDelete(): e=" EID_FMTX " EOBJ=%d l=%d "
-                      "ncon=%d\n",
-                      me,EID_PRTX(pe),OBJT(pe),level,NC(theGrid)))
-
   /* dispose element without connections (false) */
-  if (DisposeElement(theGrid, pe, false)) ASSERT(0);
+  if (DisposeElement(theGrid, pe))
+    ASSERT(0);
 }
 
 
@@ -1263,7 +839,7 @@ static void ElementDelete (DDD::DDDContext& context, DDD_OBJ obj)
 /* Purpose:   initiate dependent copy of data related to an element.            */
 /*			  this handler is implemented for an arbitrary element type.	*/
 /*																			*/
-/* Input:	  DDD_OBJ	obj:	the object which is transfered to proc		*/
+/* Input:	  DDD_OBJ	obj:	the object which is transferred to proc		*/
 /*			  int		proc:	destination processor for that object		*/
 /*			  int		prio:	priority of object new local object			*/
 /*																			*/
@@ -1308,7 +884,7 @@ static void ElementXferCopy (DDD::DDDContext& context, DDD_OBJ obj, DDD_PROC pro
     /* add edges of element */
     /* must be done before any XferCopyObj-call! herein    */
     /* or directly after XferCopyObj-call for this element */
-            #ifdef __TWODIM__
+            #ifdef UG_DIM_2
     DDD_XferAddData(context, EDGES_OF_ELEM(pe), dddctrl.TypeEdge);
             #endif
   }
@@ -1344,8 +920,7 @@ static void ElementXferCopy (DDD::DDDContext& context, DDD_OBJ obj, DDD_PROC pro
       VECTOR *vec = EDVECTOR(edge);
 
       if (vec != NULL) {
-        int Size = sizeof(VECTOR)-sizeof(DOUBLE)
-               +FMT_S_VEC_TP(MGFORMAT(dddctrl.currMG),VTYPE(vec));
+        int Size = sizeof(VECTOR)-sizeof(DOUBLE) + FMT_S_VEC_TP;
         PRINTDEBUG(dddif,3,(PFMT " ElementXferCopy():  e=" EID_FMTX
                             " EDGEVEC=" VINDEX_FMTX " size=%d\n",
                             me,EID_PRTX(pe),VINDEX_PRTX(vec),Size))
@@ -1362,8 +937,7 @@ static void ElementXferCopy (DDD::DDDContext& context, DDD_OBJ obj, DDD_PROC pro
     vec = EVECTOR(pe);
 
     if (vec != NULL) {
-      Size = sizeof(VECTOR)-sizeof(DOUBLE)
-             +FMT_S_VEC_TP(MGFORMAT(dddctrl.currMG),VTYPE(vec));
+      Size = sizeof(VECTOR)-sizeof(DOUBLE) + FMT_S_VEC_TP;
 
       PRINTDEBUG(dddif,2,(PFMT " ElementXferCopy(): e=" EID_FMTX
                           " ELEMVEC=" VINDEX_FMTX " size=%d\n",
@@ -1381,8 +955,7 @@ static void ElementXferCopy (DDD::DDDContext& context, DDD_OBJ obj, DDD_PROC pro
       vec = SVECTOR(pe,i);
 
       if (vec != NULL) {
-        Size = sizeof(VECTOR)-sizeof(DOUBLE)
-               +FMT_S_VEC_TP(MGFORMAT(dddctrl.currMG),VTYPE(vec));
+        Size = sizeof(VECTOR)-sizeof(DOUBLE) + FMT_S_VEC_TP;
 
         PRINTDEBUG(dddif,2,(PFMT " ElementXferCopy(): e=" EID_FMTX
                             " SIDEVEC=" VINDEX_FMTX " size=%d\n",
@@ -1396,7 +969,7 @@ static void ElementXferCopy (DDD::DDDContext& context, DDD_OBJ obj, DDD_PROC pro
 
 /****************************************************************************/
 
-#ifdef __TWODIM__
+#ifdef UG_DIM_2
 static void ElemGatherEdge (DDD::DDDContext& context, ELEMENT *pe, int cnt, char *data)
 {
   INT i;
@@ -1563,7 +1136,7 @@ static void ElemScatterEdge (DDD::DDDContext& context, ELEMENT *pe, int cnt, cha
         }
   }
 }
-#endif /* end __TWODIM__ */
+#endif /* end UG_DIM_2 */
 
 
 /****************************************************************************/
@@ -1577,7 +1150,7 @@ static void ElemGatherI (DDD::DDDContext& context, DDD_OBJ obj, int cnt, DDD_TYP
     return;
   }
 
-    #ifdef __TWODIM__
+    #ifdef UG_DIM_2
   /* now: type_id is always TypeEdge */
   ElemGatherEdge(context, (ELEMENT *)obj, cnt, (char *)data);
         #endif
@@ -1593,7 +1166,7 @@ static void ElemScatterI (DDD::DDDContext& context, DDD_OBJ obj, int cnt, DDD_TY
     return;
   }
 
-    #ifdef __TWODIM__
+    #ifdef UG_DIM_2
   /* type_id is always TypeEdge */
   ElemScatterEdge(context, (ELEMENT *)obj, cnt, (char *)data, newness);
         #endif
@@ -1620,7 +1193,7 @@ static void ElemGatherB (DDD::DDDContext& context, DDD_OBJ obj, int cnt, DDD_TYP
   }
 
   /* now: type_id is TypeEdge or other */
-        #ifdef __TWODIM__
+        #ifdef UG_DIM_2
   if (type_id==ddd_ctrl(context).TypeEdge)
   {
     ElemGatherEdge(context, pe, cnt, (char *)data);
@@ -1653,7 +1226,7 @@ static void ElemScatterB (DDD::DDDContext& context, DDD_OBJ obj, int cnt, DDD_TY
   }
 
   /* now: type_id is TypeEdge or other */
-        #ifdef __TWODIM__
+        #ifdef UG_DIM_2
   if (type_id==ddd_ctrl(context).TypeEdge)
   {
     ElemScatterEdge(context, pe, cnt, (char *)data, newness);
@@ -1813,7 +1386,7 @@ static void ElementObjMkCons (DDD::DDDContext& context, DDD_OBJ obj, int newness
     }
   }
 
-        #ifdef __THREEDIM__
+        #ifdef UG_DIM_3
   /* update element count of edges for new created elements */
   if (newness == XFER_NEW)
     /* increment elem counter in edges */
@@ -1854,7 +1427,7 @@ static void ElementPriorityUpdate (DDD::DDDContext& context, DDD_OBJ obj, DDD_PR
   ELEMENT *succe          = SUCCE(pe);
   INT level           = LEVEL(pe);
   GRID    *theGrid        = GetGridOnDemand(ddd_ctrl(context).currMG,level);
-  INT old                     = EPRIO(pe);
+  const DDD_PRIO old = EPRIO(pe);
   INT lostson         = 1;
 
   PRINTDEBUG(dddif,1,(PFMT "  ElementPriorityUpdate(): e=" EID_FMTX
@@ -1865,7 +1438,7 @@ static void ElementPriorityUpdate (DDD::DDDContext& context, DDD_OBJ obj, DDD_PR
   /*  if called with prio old=ghost and new=ghost,
           then you have to unlink and link again to avoid
           decoupling of son and father.
-          Sample cenario:
+          Sample scenario:
                   father=a  son=x are on proc p.
                   father is deleted and removes his reference in son,
                   but father and son are sent again to p. Son x gets
@@ -1978,8 +1551,6 @@ static void ElementPriorityUpdate (DDD::DDDContext& context, DDD_OBJ obj, DDD_PR
        */
     }
   }
-
-  return;
 }
 
 /****************************************************************************/
@@ -2105,7 +1676,6 @@ void NS_DIM_PREFIX ObjectPriorityUpdate (DDD::DDDContext& context, DDD_OBJ obj,
     break;
   default : std::abort();
   }
-  return;
 }
 
 /****************************************************************************/
@@ -2119,7 +1689,7 @@ static void ElemHandlerInit (DDD::DDDContext& context, DDD_TYPE etype, INT handl
   DDD_SetHandlerXFERCOPY        (context, etype, ElementXferCopy);
   DDD_SetHandlerSETPRIORITY     (context, etype, ElementPriorityUpdate);
 
-        #ifdef __THREEDIM__
+        #ifdef UG_DIM_3
   DDD_SetHandlerUPDATE          (context, etype, ElementUpdate);
         #endif
 
@@ -2175,9 +1745,6 @@ void NS_DIM_PREFIX ddd_HandlerInit (DDD::DDDContext& context, INT handlerSet)
 
   DDD_SetHandlerUPDATE           (context, dddctrl.TypeVector, VectorUpdate);
   DDD_SetHandlerXFERCOPY         (context, dddctrl.TypeVector, VectorXferCopy);
-  DDD_SetHandlerXFERGATHERX      (context, dddctrl.TypeVector, VectorGatherMatX);
-  DDD_SetHandlerXFERSCATTERX     (context, dddctrl.TypeVector, VectorScatterConnX);
-  DDD_SetHandlerOBJMKCONS        (context, dddctrl.TypeVector, VectorObjMkCons);
   DDD_SetHandlerSETPRIORITY      (context, dddctrl.TypeVector, VectorPriorityUpdate);
   /* TODO: not used
           DDD_SetHandlerDELETE           (context, dddctrl.TypeVector, VectorDelete);
@@ -2205,7 +1772,7 @@ void NS_DIM_PREFIX ddd_HandlerInit (DDD::DDDContext& context, INT handlerSet)
 
 
 
-        #ifdef __TWODIM__
+        #ifdef UG_DIM_2
   IElemHandlerInit(context, dddctrl.TypeTrElem, handlerSet);
   BElemHandlerInit(context, dddctrl.TypeTrBElem, handlerSet);
 
@@ -2213,7 +1780,7 @@ void NS_DIM_PREFIX ddd_HandlerInit (DDD::DDDContext& context, INT handlerSet)
   BElemHandlerInit(context, dddctrl.TypeQuBElem, handlerSet);
         #endif
 
-        #ifdef __THREEDIM__
+        #ifdef UG_DIM_3
   IElemHandlerInit(context, dddctrl.TypeTeElem, handlerSet);
   BElemHandlerInit(context, dddctrl.TypeTeBElem, handlerSet);
 
