@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 /****************************************************************************/
@@ -180,10 +182,10 @@ static void ddd_InitGenericElement(DDD::DDDContext& context, INT tag, DDD_TYPE d
                  EL_OBJPTR, r+n_offset[tag]*sizeof(void*),       ps*desc->corners_of_elem, dddctrl.TypeNode,
                  EL_OBJPTR, r+father_offset[tag]*sizeof(void*),  ps,                       dddType,
                  /* TODO: delete
-                    #ifdef __TWODIM__
+                    #ifdef UG_DIM_2
                                  EL_LDATA, r+sons_offset[tag]*sizeof(void*),    ps*desc->max_sons_of_elem,
                     #endif
-                    #ifdef __THREEDIM__
+                    #ifdef UG_DIM_3
                                  EL_LDATA, r+sons_offset[tag]*sizeof(void*),    ps*1,
                     #endif
                   */
@@ -199,7 +201,7 @@ static void ddd_InitGenericElement(DDD::DDDContext& context, INT tag, DDD_TYPE d
                    EL_OBJPTR, r+evector_offset[tag]*sizeof(void*), ps*1,     dddctrl.TypeVector,
                    EL_CONTINUE);
 
-        #ifdef __THREEDIM__
+        #ifdef UG_DIM_3
   if (ddd_ctrl(context).sideData)
     DDD_TypeDefine(context, dddType,
                    EL_OBJPTR, r+svector_offset[tag]*sizeof(void*), ps*desc->sides_of_elem, dddctrl.TypeVector,
@@ -286,7 +288,7 @@ static void ddd_DeclareTypes(DDD::DDDContext& context)
             TODO remove this clumsy exception! how?
 
           - variables TypeXXXX containing the proper DDD_TYPEs may be
-            superfluous. it would be possible to replace all occurences
+            superfluous. It would be possible to replace all occurrences
             by macros like DDDType(VEOBJ), which would be implemented as
      #define DDDType(ugtype)  (ddd_ctrl(context).types[ugtype])
             TODO check this!
@@ -317,14 +319,14 @@ static void ddd_DeclareTypes(DDD::DDDContext& context)
   MAP_TYPES(NDOBJ, dddctrl.TypeNode);
   dddctrl.dddObj[NDOBJ] = true;
 
-        #ifdef __TWODIM__
+        #ifdef UG_DIM_2
   dddctrl.TypeTrElem  = DDD_TypeDeclare(context, "TrElem");
   dddctrl.TypeTrBElem = DDD_TypeDeclare(context, "TrBElem");
   dddctrl.TypeQuElem  = DDD_TypeDeclare(context, "QuElem");
   dddctrl.TypeQuBElem = DDD_TypeDeclare(context, "QuBElem");
         #endif /* TWODIM */
 
-        #ifdef __THREEDIM__
+        #ifdef UG_DIM_3
   dddctrl.TypeTeElem  = DDD_TypeDeclare(context, "TeElem");
   dddctrl.TypeTeBElem = DDD_TypeDeclare(context, "TeBElem");
   dddctrl.TypePyElem  = DDD_TypeDeclare(context, "PyElem");
@@ -344,9 +346,6 @@ static void ddd_DeclareTypes(DDD::DDDContext& context)
 
   /* 2. DDD data objects (without DDD_HEADER) */
 
-  dddctrl.TypeMatrix = DDD_TypeDeclare(context, "Matrix");
-  MAP_TYPES(MAOBJ, dddctrl.TypeMatrix);
-
   dddctrl.TypeBndP = DDD_TypeDeclare(context, "BndP");
   static const INT objtBndP = GetFreeOBJT();
   MAP_TYPES(objtBndP, dddctrl.TypeBndP);
@@ -404,10 +403,9 @@ static void ddd_DefineTypes(DDD::DDDContext& context)
                  EL_LDATA,  ELDEF(VECTOR,succ),
                  EL_GDATA,  ELDEF(VECTOR,index),
                  EL_GDATA,  ELDEF(VECTOR,leafIndex),
-                 EL_LDATA,  ELDEF(VECTOR,start),
 
-                 /* TODO: value wird noch ausgelassen. feld variabler laenge? */
-                 /* bei entscheidung 'value': kein weiteres feld
+                 /* TODO: value wird noch ausgelassen. Feld variabler Laenge? */
+                 /* bei Entscheidung 'value': kein weiteres Feld
                          bei ent. 'userdata *': EL_GDATA-feld        */
                  EL_GDATA,  ELDEF(VECTOR,value),
                  EL_END,    sizeof(VECTOR)
@@ -438,14 +436,14 @@ static void ddd_DefineTypes(DDD::DDDContext& context)
                  EL_LDATA,  ELDEF(ivertex,succ),
                  EL_LDATA,  ELDEF(ivertex,data),
 
-                 /* TODO muss father LDATA oder OBJPTR sein?     */
-                 /* LDATA, father ist nur lokal gueltig und      */
-                 /* ist abhaengig von vertikaler Lastverteilung  */
-                #ifdef __TWODIM__
+                 /* TODO Does father have to be LDATA or OBJPTR?     */
+                 /* LDATA, father is valid only locally,             */
+                 /* and depends on vertical load balancing.          */
+                #ifdef UG_DIM_2
                  /* TODO: ref-typ muss eigentlich {TypeTrElem,TypeTrBElem} sein! */
                  EL_OBJPTR, ELDEF(ivertex,father), dddctrl.TypeTrElem,
                 #endif
-                #ifdef __THREEDIM__
+                #ifdef UG_DIM_3
                  EL_LDATA,  ELDEF(ivertex,father),
                 #endif
 
@@ -476,14 +474,14 @@ static void ddd_DefineTypes(DDD::DDDContext& context)
                  EL_LDATA,  ELDEF(bvertex,succ),
                  EL_LDATA,  ELDEF(bvertex,data),
 
-                 /* TODO muss father LDATA oder OBJPTR sein?     */
-                 /* LDATA, father ist nur lokal gueltig und      */
-                 /* ist abhaengig von vertikaler Lastverteilung  */
-                #ifdef __TWODIM__
+                 /* TODO Does father have to be LDATA or OBJPTR?     */
+                 /* LDATA, father is valid only locally,             */
+                 /* and depends on vertical load balancing.          */
+                #ifdef UG_DIM_2
                  /* TODO: ref-typ muss eigentlich {TypeTrElem,TypeTrBElem} sein! */
                  EL_OBJPTR, ELDEF(bvertex,father), dddctrl.TypeTrElem,
                 #endif
-                #ifdef __THREEDIM__
+                #ifdef UG_DIM_3
                  EL_LDATA,  ELDEF(bvertex,father),
                 #endif
 
@@ -510,7 +508,7 @@ static void ddd_DefineTypes(DDD::DDDContext& context)
                  EL_LDATA,  ELDEF(NODE,pred),
                  EL_LDATA,  ELDEF(NODE,succ),
 
-                 /* TODO was ist start? */
+                 /* TODO What is start? */
                  EL_LDATA,  ELDEF(NODE,start),
 
                  /* father may be one of node or edge */
@@ -522,33 +520,21 @@ static void ddd_DefineTypes(DDD::DDDContext& context)
                  EL_OBJPTR, ELDEF(NODE,myvertex), dddctrl.TypeIVertex,
                  EL_CONTINUE);
 
-  if (ddd_ctrl(context).nodeData)
-    DDD_TypeDefine(context, dddctrl.TypeNode,
-                   EL_OBJPTR, ELDEF(NODE,vector), dddctrl.TypeVector,
-                   EL_CONTINUE);
-
-  /* The size of a NODE object may be less than sizeof(NODE).
-   * Indeed, if the format does not contain node data, then the corresponding VECTOR*
-   * data member that stores this data is removed from the NODE object.  Hence the
-   * size of the NODE decreases by the size of one VECTOR*.
-   * Compare the corresponding computation in the method CreateNode (in ugm.c)
-   */
-  size = sizeof(NODE) - (dddctrl.nodeData ? 0 : sizeof(VECTOR*));
   DDD_TypeDefine(context, dddctrl.TypeNode,
-                 EL_END, size);
+                 EL_END, sizeof(NODE));
 
   /* set mergemode to maximum */
   DDD_PrioMergeDefault(context, dddctrl.TypeNode, PRIOMERGE_MAXIMUM);
 
 
-        #ifdef __TWODIM__
+        #ifdef UG_DIM_2
   ddd_InitGenericElement(context, TRIANGLE,      dddctrl.TypeTrElem,  Inside);
   ddd_InitGenericElement(context, TRIANGLE,      dddctrl.TypeTrBElem, Boundary);
   ddd_InitGenericElement(context, QUADRILATERAL, dddctrl.TypeQuElem,  Inside);
   ddd_InitGenericElement(context, QUADRILATERAL, dddctrl.TypeQuBElem, Boundary);
         #endif /* TWODIM */
 
-        #ifdef __THREEDIM__
+        #ifdef UG_DIM_3
   ddd_InitGenericElement(context, TETRAHEDRON, dddctrl.TypeTeElem,  Inside);
   ddd_InitGenericElement(context, TETRAHEDRON, dddctrl.TypeTeBElem, Boundary);
   ddd_InitGenericElement(context, PYRAMID,     dddctrl.TypePyElem,  Inside);
@@ -561,19 +547,6 @@ static void ddd_DefineTypes(DDD::DDDContext& context)
 
   /* 2. DDD data objects (without DDD_HEADER) */
 
-  /* NOTE: the size of matrix objects computed by the DDD Typemanager
-     will not be the real size ued by DDD. this size has to be computed
-     by UG_MSIZE(mat). this is relevant only in gather/scatter of matrices
-     in handler.c. */
-  DDD_TypeDefine(context, dddctrl.TypeMatrix,
-                 EL_GDATA,  ELDEF(MATRIX,control),
-                 EL_LDATA,  ELDEF(MATRIX,next),
-                 EL_OBJPTR, ELDEF(MATRIX,vect),   dddctrl.TypeVector,
-                 /* TODO: not needed
-                    EL_LDATA,  ELDEF(MATRIX,value), */
-                 EL_END,    sizeof(MATRIX)
-                 );
-
   /* compute global fields it control word entry */
   gbits = ~(((1<<NO_OF_ELEM_LEN)-1)<<NO_OF_ELEM_SHIFT);
   PRINTDEBUG(dddif,1,("ddd_DefineTypes(): TypeEdge gbits=%08x size=%d\n",
@@ -582,10 +555,10 @@ static void ddd_DefineTypes(DDD::DDDContext& context)
   DDD_TypeDefine(context, dddctrl.TypeEdge,
                  /* link 0 data */
                  /*TODO: now unique
-                    #ifdef __TWODIM__
+                    #ifdef UG_DIM_2
                                  EL_GDATA,  ELDEF(EDGE,links[0].control),
                     #endif
-                    #ifdef __THREEDIM__
+                    #ifdef UG_DIM_3
                                  EL_LDATA,  ELDEF(EDGE,links[0].control),
                     #endif
                   */
@@ -654,13 +627,13 @@ static void ddd_IfInit(DDD::DDDContext& context)
 
 
   /* define element interfaces */
-#ifdef __TWODIM__
+#ifdef UG_DIM_2
   O[0] = dddctrl.TypeTrElem; O[1] = dddctrl.TypeTrBElem;
   O[2] = dddctrl.TypeQuElem; O[3] = dddctrl.TypeQuBElem;
   nO = 4;
 #endif
 
-#ifdef __THREEDIM__
+#ifdef UG_DIM_3
   O[0] = dddctrl.TypeTeElem; O[1] = dddctrl.TypeTeBElem;
   O[2] = dddctrl.TypePyElem; O[3] = dddctrl.TypePyBElem;
   O[4] = dddctrl.TypePrElem; O[5] = dddctrl.TypePrBElem;
@@ -866,14 +839,14 @@ static void InitDDDTypes(DDD::DDDContext& context)
   DDD_TypeDisplay(context, dddctrl.TypeNode);
   DDD_TypeDisplay(context, dddctrl.TypeEdge);
 
-        #ifdef __TWODIM__
+        #ifdef UG_DIM_2
   DDD_TypeDisplay(context, dddctrl.TypeTrElem);
   DDD_TypeDisplay(context, dddctrl.TypeTrBElem);
   DDD_TypeDisplay(context, dddctrl.TypeQuElem);
   DDD_TypeDisplay(context, dddctrl.TypeQuBElem);
         #endif
 
-        #ifdef __THREEDIM__
+        #ifdef UG_DIM_3
   DDD_TypeDisplay(context, dddctrl.TypeTeElem);
   DDD_TypeDisplay(context, dddctrl.TypeTeBElem);
   DDD_TypeDisplay(context, dddctrl.TypePyElem);
@@ -885,8 +858,7 @@ static void InitDDDTypes(DDD::DDDContext& context)
         #endif
 
   /* display dependent types */
-  DDD_TypeDisplay(context, dddctrl.TypeMatrix);
-        #ifdef __TWODIM__
+        #ifdef UG_DIM_2
   DDD_TypeDisplay(context, dddctrl.TypeEdge);
         #endif
   ENDDEBUG
@@ -920,26 +892,12 @@ void NS_DIM_PREFIX InitCurrMG (MULTIGRID *MG)
   auto& dddctrl = ddd_ctrl(MG->dddContext());
   dddctrl.currMG = MG;
 
-  dddctrl.nodeData = VEC_DEF_IN_OBJ_OF_MG(dddctrl.currMG,NODEVEC);
-  dddctrl.edgeData = VEC_DEF_IN_OBJ_OF_MG(dddctrl.currMG,EDGEVEC);
-  dddctrl.elemData = VEC_DEF_IN_OBJ_OF_MG(dddctrl.currMG,ELEMVEC);
+  dddctrl.nodeData = 0;
+  dddctrl.edgeData = 0;
+  dddctrl.elemData = 0;
   dddctrl.sideData = VEC_DEF_IN_OBJ_OF_MG(dddctrl.currMG,SIDEVEC);
 
-  if (dddctrl.currFormat == NULL)
-  {
-    /* InitCurrMG was called for the first time, init
-       DDD-types now. */
-    InitDDDTypes(MG->dddContext());
-    dddctrl.currFormat = MG->theFormat.get();
-  }
-  else
-  {
-    /* InitCurrMG has been called before. This is not allowed,
-       cf. comment in ugm.c(DisposeMultiGrid()). */
-    PrintErrorMessage('E',"InitCurrMG",
-                      "opening more than one MG is not allowed in parallel");
-    ASSERT(0); exit(1);
-  }
+  InitDDDTypes(MG->dddContext());
 }
 
 
@@ -1058,7 +1016,6 @@ int NS_DIM_PREFIX InitDDD(DDD::DDDContext& context)
   {
     dddctrl.ugtypes[i] = -1;
   }
-  dddctrl.currFormat = NULL;
 
   /* declare DDD_TYPES, definition must be done later */
   ddd_DeclareTypes(context);
@@ -1093,7 +1050,7 @@ int NS_DIM_PREFIX InitDDD(DDD::DDDContext& context)
    DESCRIPTION:
    This function exits the parallel application on ddd level
 
-   RETUR
+   RETURN
    N VALUE:
    void
  */
