@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 /****************************************************************************/
@@ -192,17 +194,14 @@ static INT UpdateElementOverlap (DDD::DDDContext& context, ELEMENT *theElement)
       /* send son to all elements where theNeighbor is master, vghost or vhghost */
       if (0)
       {
-        int *proclist = EPROCLIST(context, theNeighbor);
-        proclist += 2;
-        while (*proclist != -1)
+        for (auto&& [proc, prio] : DDD_InfoProcListRange(context, PARHDRE(theNeighbor), false))
         {
-          if (!EHGHOSTPRIO(*(proclist+1)))
+          if (!EHGHOSTPRIO(prio))
           {
-            XFERECOPYX(context, theSon,*proclist,PrioHGhost,
+            XFERECOPYX(context, theSon,proc,PrioHGhost,
                        (OBJT(theSon)==BEOBJ) ? BND_SIZE_TAG(TAG(theSon)) :
                        INNER_SIZE_TAG(TAG(theSon)));
           }
-          proclist += 2;
         }
       }
     }
@@ -369,10 +368,10 @@ INT ConnectGridOverlap (GRID *theGrid)
       if (!THEFLAG(theElement) && !THEFLAG(theNeighbor)) continue;
 
       /* connect only TO master copies */
-                        #ifdef __TWODIM__
+                        #ifdef UG_DIM_2
       if (!IS_REFINED(theNeighbor) || !MASTERPRIO(prio)) continue;
                         #endif
-                        #ifdef __THREEDIM__
+                        #ifdef UG_DIM_3
       if (!IS_REFINED(theNeighbor)) continue;
                         #endif
 
@@ -447,7 +446,7 @@ INT ConnectGridOverlap (GRID *theGrid)
             UserWriteF("ConnectGridOverlap(): disposing useless yellow ghost  e=" EID_FMTX
                        "f=" EID_FMTX "this ghost is useless!\n",
                        EID_PRTX(theSon),EID_PRTX(theElement));
-            DisposeElement(UPGRID(theGrid),theSon,true);
+            DisposeElement(UPGRID(theGrid),theSon);
           }
           else
           {
@@ -657,7 +656,7 @@ static INT ConnectOverlapVerticalGrid (GRID *theGrid)
 
   for (theElement=PFIRSTELEMENT(theGrid); theElement!=NULL; theElement=SUCCE(theElement))
   {
-    /* reconstuct node relations using element relations */
+    /* reconstruct node relations using element relations */
     if (GetAllSons(theElement,SonList) != GM_OK) REP_ERR_RETURN(1);
     for (i=0; SonList[i]!=NULL; i++)
     {
@@ -722,7 +721,7 @@ static INT ConnectOverlapVerticalGrid (GRID *theGrid)
               assert (MIDNODE(theEdge)==NULL ||
                       MIDNODE(theEdge) == SonNode);
 
-                                                                #ifdef __TWODIM__
+                                                                #ifdef UG_DIM_2
               IFDEBUG(dddif,1)
               printf("ConnectOverlapVerticalGrid(): new "
                      " midnode relation between theEdge=%p"
@@ -731,7 +730,7 @@ static INT ConnectOverlapVerticalGrid (GRID *theGrid)
                      VID_PRTX(MYVERTEX(SonNode)));
               ENDDEBUG
                                                                 #endif
-                                                                #ifdef __THREEDIM__
+                                                                #ifdef UG_DIM_3
               printf("ConnectOverlapVerticalGrid(): new "
                      " midnode relation between theEdge=" ID_FMTX
                      " SonNode=" ID_FMTX "\n",
