@@ -1,5 +1,7 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
+// SPDX-FileCopyrightInfo: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 /****************************************************************************/
 /*                                                                                                                                                      */
 /* File:          parallel.h                                                                                                    */
@@ -214,7 +216,6 @@ struct DDD_CTRL
 {
   /* data from ug */
   MULTIGRID *currMG;
-  FORMAT    *currFormat;
   int nodeData;
   int edgeData;
   int elemData;
@@ -234,11 +235,11 @@ struct DDD_CTRL
 
   DDD_TYPE TypeUnknown;
 
-#ifdef __TWODIM__
+#ifdef UG_DIM_2
   DDD_TYPE TypeTrElem, TypeTrBElem, TypeQuElem, TypeQuBElem;
 #endif
 
-#ifdef __THREEDIM__
+#ifdef UG_DIM_3
   DDD_TYPE TypeTeElem, TypeTeBElem;
   DDD_TYPE TypePyElem, TypePyBElem;
   DDD_TYPE TypePrElem, TypePrBElem;
@@ -246,7 +247,6 @@ struct DDD_CTRL
 #endif
 
   /* DDD data objects */
-  DDD_TYPE TypeMatrix;
   DDD_TYPE TypeBndP;
   DDD_TYPE TypeEdge;
   DDD_TYPE TypeBndS;
@@ -318,7 +318,7 @@ void    ConstructConsistentGrid                 (GRID *theGrid);
 void    ConstructConsistentMultiGrid    (MULTIGRID *theMG);
 
 /* from pgmcheck.c */
-INT                     CheckProcListCons (int *proclist, int uniqueTag);
+INT             CheckProcListCons(const DDD_InfoProcListRange& proclist, DDD_PRIO uniqueTag);
 INT             CheckInterfaces                         (GRID *theGrid);
 
 /* from priority.c */
@@ -354,29 +354,31 @@ INT             RestrictPartitioning            (MULTIGRID *theMG);
 INT             CheckInterfaces                         (GRID *theGrid);
 
 /*
- * COMPATABILITY FUNCTIONS FOR OLDER dune-grid RELEASES
+ * COMPATIBILITY FUNCTIONS FOR OLDER dune-grid RELEASES
  */
 
 /**
  * get global DDD context.
- * This only exists for compatability with old versions of dune-grid.
+ * This only exists for compatibility with old versions of dune-grid.
  */
 DDD::DDDContext& globalDDDContext();
 
 /**
  * set global DDD context.
- * This only exists for compatability with old versions of dune-grid.
+ * This only exists for compatibility with old versions of dune-grid.
  */
 void globalDDDContext(const std::shared_ptr<DDD::DDDContext>& context);
 
 /**
  * invalidate global DDD context.
- * This only exists for compatability with old versions of dune-grid.
+ * This only exists for compatibility with old versions of dune-grid.
  */
 void globalDDDContext(std::nullptr_t);
 
 using ComProcPtr = int (*)(DDD_OBJ, void *);
+[[deprecated("Use `DDD_IFOneway(context, ...)` instead")]]
 void DDD_IFOneway(DDD_IF, DDD_IF_DIR, size_t, ComProcPtr, ComProcPtr);
+[[deprecated("Use `DDD_InfoProcListRange` instead")]]
 int* DDD_InfoProcList(DDD_HDR);
 
 #endif /* ModelP */
