@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 /****************************************************************************/
@@ -251,7 +253,7 @@ static int Scatter_ElementRestriction (DDD::DDDContext&, DDD_OBJ obj, void *data
   {
     PRINTDEBUG(gm,4,(PFMT "Scatter_ElementRestriction(): restricting sons of e=" EID_FMTX "\n",
                      me,EID_PRTX(theElement)))
-    used = MAX(USED(theElement),((int *)data)[0]);
+    used = std::max((INT)USED(theElement),((int *)data)[0]);
     SETUSED(theElement,used);
   }
 
