@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 /****************************************************************************/
@@ -62,6 +64,7 @@ using namespace PPIF;
 /****************************************************************************/
 
 #define CHECK_OBJECT_PRIO(o,prio,master,ghost,id,s,_nerr_)                   \
+  do { \
   if (USED(o)==1 && ! master (o))                                          \
   {                                                                        \
     UserWriteF("MASTER %s=" id ## _FMTX " has WRONG prio=%d\n",      \
@@ -73,7 +76,8 @@ using namespace PPIF;
     UserWriteF("GHOST %s=" id ## _FMTX " has WRONG prio=%d\n",       \
                s, id ## _PRTX( o ),prio(o));                                \
     _nerr_++;                                                        \
-  }
+  } \
+  } while (0)
 
 /****************************************************************************/
 /*																			*/
@@ -112,7 +116,7 @@ static INT check_distributed_objects_errors = 0;
    CheckProcListCons -
 
    SYNOPSIS:
-   INT CheckProcListCons (int *proclist, int uniqueTag);
+   INT CheckProcListCons (const DDD_InfoProcListRange& proclist, DDD_PRIO uniqueTag);
 
    PARAMETERS:
    .  proclist
@@ -125,21 +129,21 @@ static INT check_distributed_objects_errors = 0;
  */
 /****************************************************************************/
 
-INT NS_DIM_PREFIX CheckProcListCons (int *proclist, int uniqueTag)
+INT NS_DIM_PREFIX CheckProcListCons (const DDD_InfoProcListRange& proclist, DDD_PRIO uniqueTag)
 {
   int nunique = 0;
 
   /* check uniqueness */
-  while (*proclist != -1)
+  for (auto&& [proc, prio] : proclist)
   {
-    if (*(proclist+1) == uniqueTag) nunique++;
-    proclist += 2;
+    if (prio == uniqueTag)
+      ++nunique;
   }
 
   /* nunique must be 1 for master elements   */
   /* nunique can  be 0/1 for (inner) nodes   */
   /*   with PrioBorder/PrioMaster            */
-  return (nunique);
+  return nunique;
 }
 
 
@@ -149,7 +153,7 @@ INT NS_DIM_PREFIX CheckProcListCons (int *proclist, int uniqueTag)
    ListProcList -
 
    SYNOPSIS:
-   INT ListProcList (int *proclist, int uniqueTag);
+   INT ListProcList (const DDD_InfoProcListRange& proclist, DDD_PRIO uniqueTag);
 
    PARAMETERS:
    .  proclist
@@ -162,15 +166,14 @@ INT NS_DIM_PREFIX CheckProcListCons (int *proclist, int uniqueTag)
  */
 /****************************************************************************/
 
-static INT ListProcList (int *proclist, int uniqueTag)
+static INT ListProcList (const DDD_InfoProcListRange& proclist, DDD_PRIO uniqueTag)
 {
-  while (*proclist != -1)
+  for (auto&& [proc, prio] : proclist)
   {
-    if (*(proclist+1) == uniqueTag)
-      UserWriteF(" proc=%d",*proclist);
-    proclist += 2;
+    if (prio == uniqueTag)
+      UserWriteF(" proc=%d", proc);
   }
-  return(0);
+  return 0;
 }
 
 
@@ -198,19 +201,20 @@ static INT CheckVectorPrio (DDD::DDDContext& context, ELEMENT *theElement, VECTO
   INT nerrors = 0;
 
   /* check vector prio */
-  CHECK_OBJECT_PRIO(theVector,PRIO,MASTER,GHOST,VINDEX,"Vector",nerrors)
+  CHECK_OBJECT_PRIO(theVector,PRIO,MASTER,GHOST,VINDEX,"Vector",nerrors);
 
   /* master copy has to be unique */
-  if ((nmaster = CheckProcListCons(PROCLIST(context, theVector),PrioMaster)) > 1)
+  const auto& proclist = DDD_InfoProcListRange(context, PARHDR(theVector));
+  if ((nmaster = CheckProcListCons(proclist, PrioMaster)) > 1)
   {
     UserWriteF("VECTOR=" ID_FMTX " ERROR: master copy not unique, nmaster=%d:",
                ID_PRTX(theVector),nmaster);
-    ListProcList(PROCLIST(context, theVector),PrioMaster);
+    ListProcList(proclist, PrioMaster);
     UserWriteF("\n");
     nerrors++;
   }
 
-  return(nerrors);
+  return nerrors;
 }
 
 
@@ -238,26 +242,19 @@ static INT CheckNodePrio (DDD::DDDContext& context, ELEMENT *theElement, NODE *t
   INT nerrors = 0;
 
   /* check node prio */
-  CHECK_OBJECT_PRIO(theNode,PRIO,MASTER,GHOST,ID,"NODE",nerrors)
+  CHECK_OBJECT_PRIO(theNode,PRIO,MASTER,GHOST,ID,"NODE",nerrors);
 
   /* master copy has to be unique */
-    if ((nmaster = CheckProcListCons(PROCLIST(context, theNode),PrioMaster)) > 1)
+  const auto& proclist = DDD_InfoProcListRange(context, PARHDR(theNode));
+  if ((nmaster = CheckProcListCons(proclist, PrioMaster)) > 1)
   {
     UserWriteF("NODE=" ID_FMTX " ERROR: master copy not unique, nmaster=%d:",
                ID_PRTX(theNode),nmaster);
-    ListProcList(PROCLIST(context, theNode),PrioMaster);
+    ListProcList(proclist, PrioMaster);
     UserWriteF("\n");
     nerrors++;
   }
 
-  if (ddd_ctrl(context).nodeData)
-  {
-    if (NVECTOR(theNode) != NULL)
-    {
-      nerrors += CheckVectorPrio(context, theElement,NVECTOR(theNode));
-    }
-  }
-
   return(nerrors);
 }
 
@@ -284,18 +281,19 @@ static INT CheckEdgePrio (DDD::DDDContext& context, ELEMENT *theElement, EDGE *t
 {
   INT nerrors = 0;
 
-        #ifdef __THREEDIM__
+        #ifdef UG_DIM_3
   INT nmaster;
 
   /* check edge prio */
-  CHECK_OBJECT_PRIO(theEdge,PRIO,MASTER,GHOST,ID,"EDGE",nerrors)
+  CHECK_OBJECT_PRIO(theEdge,PRIO,MASTER,GHOST,ID,"EDGE",nerrors);
 
   /* master copy has to be unique */
-  if ((nmaster = CheckProcListCons(PROCLIST(context, theEdge),PrioMaster)) > 1)
+  const auto& proclist = DDD_InfoProcListRange(context, PARHDR(theEdge));
+  if ((nmaster = CheckProcListCons(proclist, PrioMaster)) > 1)
   {
     UserWriteF("EDGE=" EDID_FMTX " ERROR: master copy not unique, nmaster=%d:",
                EDID_PRTX(theEdge),nmaster);
-    ListProcList(PROCLIST(context, theEdge),PrioMaster);
+    ListProcList(proclist, PrioMaster);
     UserWriteF("\n");
     nerrors++;
   }
@@ -367,10 +365,11 @@ static INT CheckElementPrio (DDD::DDDContext& context, ELEMENT *theElement)
   }
 
   /* check element prio */
-  CHECK_OBJECT_PRIO(theElement,EPRIO,EMASTER,EGHOST,EID,"ELEM",nerrors)
+  CHECK_OBJECT_PRIO(theElement,EPRIO,EMASTER,EGHOST,EID,"ELEM",nerrors);
 
   /* master copy has to be unique */
-  if ((nmaster = CheckProcListCons(EPROCLIST(context, theElement),PrioMaster)) != 1)
+  const auto& proclist = DDD_InfoProcListRange(context, PARHDRE(theElement));
+  if ((nmaster = CheckProcListCons(proclist, PrioMaster)) != 1)
   {
     UserWriteF("ELEM=" EID_FMTX " ERROR: master copy not unique, ",
                EID_PRTX(theElement),nmaster);
@@ -379,7 +378,7 @@ static INT CheckElementPrio (DDD::DDDContext& context, ELEMENT *theElement)
     else
       UserWrite("Father=NULL");
     UserWriteF(" nmaster=%d:",nmaster);
-    ListProcList(EPROCLIST(context, theElement),PrioMaster);
+    ListProcList(proclist, PrioMaster);
     UserWriteF("\n");
     nerrors++;
   }
@@ -473,7 +472,7 @@ static int Gather_ElemObjectGids (DDD::DDDContext&, DDD_OBJ obj, void *data, DDD
     ((DDD_GID *)data)[i] = GID(CORNER(theElement,i));
   }
 
-        #ifdef __THREEDIM__
+        #ifdef UG_DIM_3
   /* copy edge gids into buffer */
   for (INT i=CORNERS_OF_ELEM(theElement),j=0; i<EDGES_OF_ELEM(theElement); i++,j++)
   {
@@ -505,7 +504,7 @@ static int Scatter_ElemObjectGids (DDD::DDDContext&, DDD_OBJ obj, void *data, DD
     }
   }
 
-        #ifdef __THREEDIM__
+        #ifdef UG_DIM_3
   /* compare edge gids with buffer gids */
   for (INT i=CORNERS_OF_ELEM(theElement),j=0; i<EDGES_OF_ELEM(theElement); i++,j++)
   {
@@ -526,18 +525,16 @@ static int Scatter_ElemObjectGids (DDD::DDDContext&, DDD_OBJ obj, void *data, DD
   return 0;
 }
 
-#ifdef __THREEDIM__
+#ifdef UG_DIM_3
 static int Gather_EdgeObjectGids (DDD::DDDContext&, DDD_OBJ obj, void *data, DDD_PROC proc, DDD_PRIO prio)
 {
-  INT i;
   EDGE *theEdge = (EDGE *)obj;
-  NODE *theNode0, *theNode1, *MidNode;
 
-  i = 0;
+  INT i = 0;
 
-  theNode0 = NBNODE(LINK0(theEdge));
-  theNode1 = NBNODE(LINK1(theEdge));
-  MidNode  = MIDNODE(theEdge);
+  NODE* theNode0 = NBNODE(LINK0(theEdge));
+  NODE* theNode1 = NBNODE(LINK1(theEdge));
+  NODE* MidNode  = MIDNODE(theEdge);
 
   /* copy node gids into buffer */
   ((DDD_GID *)data)[i++] = GID(theNode0);
@@ -552,26 +549,24 @@ static int Gather_EdgeObjectGids (DDD::DDDContext&, DDD_OBJ obj, void *data, DDD
 
 static int Scatter_EdgeObjectGids (DDD::DDDContext& context, DDD_OBJ obj, void *data, DDD_PROC proc, DDD_PRIO prio)
 {
-  INT i;
   DDD_GID remotegid;
   EDGE *theEdge = (EDGE *)obj;
-  NODE *theNode0, *theNode1, *MidNode;
-  int *proclist = PROCLIST(context, theEdge);
 
   /* this check allows no edges copies of type VGHOST */
   /* since then midnode might be NULL due to local    */
   /* load balancing situation                         */
-  while (*proclist != -1)
+  const auto& proclist = DDD_InfoProcListRange(context, PARHDR(theEdge));
+  for (auto&& [proc, prio] : proclist)
   {
-    if (VGHOSTPRIO(*(proclist+1))) return(0);
-    proclist += 2;
+    if (VGHOSTPRIO(prio))
+      return 0;
   }
 
-  i = 0;
+  INT i = 0;
 
-  theNode0 = NBNODE(LINK0(theEdge));
-  theNode1 = NBNODE(LINK1(theEdge));
-  MidNode  = MIDNODE(theEdge);
+  NODE* theNode0 = NBNODE(LINK0(theEdge));
+  NODE* theNode1 = NBNODE(LINK1(theEdge));
+  NODE* MidNode  = MIDNODE(theEdge);
 
   /* compare node0 gids with buffer gids */
   if (((DDD_GID *)data)[i] != GID(theNode0))
@@ -637,10 +632,10 @@ static INT CheckDistributedObjects (GRID *theGrid)
   const auto& dddctrl = ddd_ctrl(context);
 
   INT nerrors;
-        #ifdef __TWODIM__
+        #ifdef UG_DIM_2
   INT size = MAX_CORNERS_OF_ELEM;       /* compare the 3/4 node ids */
         #endif
-        #ifdef __THREEDIM__
+        #ifdef UG_DIM_3
   INT size = MAX_CORNERS_OF_ELEM+MAX_EDGES_OF_ELEM;             /* compare 8 nodes + 12 edges */
         #endif
 
@@ -651,7 +646,7 @@ static INT CheckDistributedObjects (GRID *theGrid)
                  dddctrl.ElementSymmVHIF,GRID_ATTR(theGrid),IF_BACKWARD,size*sizeof(DDD_GID),
                  Gather_ElemObjectGids, Scatter_ElemObjectGids);
 
-        #ifdef __THREEDIM__
+        #ifdef UG_DIM_3
   if (0)
     DDD_IFAOnewayX(context,
                    dddctrl.BorderEdgeSymmIF,GRID_ATTR(theGrid),IF_BACKWARD,3*sizeof(DDD_GID),
@@ -713,9 +708,6 @@ INT NS_DIM_PREFIX CheckInterfaces (GRID *theGrid)
       {
         theNode = CORNER(theElement,i);
         SETUSED(theNode,j);
-        if (dddctrl.nodeData)
-          if (NVECTOR(theNode) != NULL)
-            SETUSED(NVECTOR(theNode),j);
         SETUSED(MYVERTEX(theNode),j);
       }
 
