@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 /****************************************************************************/
@@ -72,9 +74,6 @@ inline void NODE_PRIORITY_SET(DDD::DDDContext& context, GRID* grid, NODE* node,
 {
   /* set priorities of node */
   SETPRIOX(context, node, prio);
-
-  if (VEC_DEF_IN_OBJ_OF_GRID(grid, NODEVEC) and NVECTOR(node) != nullptr)
-    SETPRIOPV(context, NVECTOR(node),prio);
 }
 
 inline void PRIO_SET_EDGE(DDD::DDDContext& context, EDGE* edge, INT prio)
@@ -86,10 +85,6 @@ inline void EDGE_PRIORITY_SET(DDD::DDDContext& context, GRID* grid, EDGE* edge,
 {
   /* set priorities of node for 3D */
   PRIO_SET_EDGE(context, edge, prio);
-
-  /* set priority of edge vector */
-  if (VEC_DEF_IN_OBJ_OF_GRID(grid, EDGEVEC) and EDVECTOR(edge) != nullptr)
-    SETPRIOX(context, EDVECTOR(edge),prio);
 }
 
 
@@ -142,17 +137,15 @@ inline void EDGE_PRIORITY_SET(DDD::DDDContext& context, GRID* grid, EDGE* edge,
 static int ComputeNodeBorderPrios (DDD::DDDContext& context, DDD_OBJ obj)
 {
   NODE    *node  = (NODE *)obj;
-  int     *plist = DDD_InfoProcList(context, PARHDR(node));
-  int i, min_proc = context.procs();
+  int min_proc = context.procs();
 
   /*
           minimum processor number will get Master-node,
           all others get Border-nodes
    */
-  for(i=0; plist[i]>=0; i+=2)
-  {
-    if (plist[i+1]==PrioMaster && plist[i]<min_proc)
-      min_proc = plist[i];
+  for (auto&& [proc, prio] : DDD_InfoProcListRange(context, PARHDR(node))) {
+    if (prio == PrioMaster && proc < min_proc)
+      min_proc = proc;
   }
 
   if (min_proc == context.procs())
@@ -184,17 +177,15 @@ static int ComputeNodeBorderPrios (DDD::DDDContext& context, DDD_OBJ obj)
 static int ComputeVectorBorderPrios (DDD::DDDContext& context, DDD_OBJ obj)
 {
   VECTOR  *vector  = (VECTOR *)obj;
-  int     *plist = DDD_InfoProcList(context, PARHDR(vector));
-  int i, min_proc = context.procs();
+  int min_proc = context.procs();
 
   /*
           minimum processor number will get Master-node,
           all others get Border-nodes
    */
-  for(i=0; plist[i]>=0; i+=2)
-  {
-    if (plist[i+1]==PrioMaster && plist[i]<min_proc)
-      min_proc = plist[i];
+  for (auto&& [proc, prio] : DDD_InfoProcListRange(context, PARHDR(vector))) {
+    if (prio == PrioMaster && proc < min_proc)
+      min_proc = proc;
   }
 
   if (min_proc == context.procs())
@@ -227,17 +218,15 @@ static int ComputeVectorBorderPrios (DDD::DDDContext& context, DDD_OBJ obj)
 static int ComputeEdgeBorderPrios (DDD::DDDContext& context, DDD_OBJ obj)
 {
   EDGE    *edge  =        (EDGE *)obj;
-  int             *plist =        DDD_InfoProcList(context, PARHDR(edge));
-  int i, min_proc     = context.procs();
+  int min_proc     = context.procs();
 
   /*
           minimum processor number will get Master-node,
           all others get Border-nodes
    */
-  for(i=0; plist[i]>=0; i+=2)
-  {
-    if (plist[i+1]==PrioMaster && plist[i]<min_proc)
-      min_proc = plist[i];
+  for (auto&& [proc, prio] : DDD_InfoProcListRange(context, PARHDR(edge))) {
+    if (prio == PrioMaster && proc < min_proc)
+      min_proc = proc;
   }
 
   if (min_proc == context.procs())
@@ -417,13 +406,6 @@ void NS_DIM_PREFIX SetGhostObjectPriorities (GRID *theGrid)
       PRINTDEBUG(gm,1,("SetGhostObjectPriorities(): e=" EID_FMTX " new prio=%d\n",
                        EID_PRTX(theElement),prio))
       SETEPRIOX(context, theElement, prio);
-
-      if (VEC_DEF_IN_OBJ_OF_GRID(theGrid,ELEMVEC))
-      {
-        theVector = EVECTOR(theElement);
-        if (theVector != NULL)
-          SETPRIOX(context, theVector,prio);
-      }
     }
 
     /* set edge priorities */
@@ -446,7 +428,7 @@ void NS_DIM_PREFIX SetGhostObjectPriorities (GRID *theGrid)
         EDGE_PRIORITY_SET(context, theGrid,theEdge,PrioMaster);
     }
 
-                        #ifdef __THREEDIM__
+                        #ifdef UG_DIM_3
     /* if one(all) of the side nodes is (are) a hghost (vghost) node   */
     /* then its a hghost (vghost) side vector                          */
     if (VEC_DEF_IN_OBJ_OF_GRID(theGrid,SIDEVEC))
