@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 /****************************************************************************/
@@ -42,7 +44,6 @@
 #include <dune/uggrid/gm/algebra.h>
 #include <dune/uggrid/gm/evm.h>
 #include <dune/uggrid/gm/gm.h>
-#include <dune/uggrid/gm/mgheapmgr.h>
 #include <dune/uggrid/gm/refine.h>
 #include <dune/uggrid/gm/ugm.h>
 #include <dune/uggrid/low/debug.h>
@@ -749,9 +750,8 @@ static void InheritPartitionBottomTop (ELEMENT *e)
 
 int NS_DIM_PREFIX TransferGridFromLevel (MULTIGRID *theMG, INT level)
 {
-  INT g;
-  INT migrated = 0;       /* number of elements moved */
 #ifdef STAT_OUT
+  INT migrated = 0;       /* number of elements moved */
   DOUBLE trans_begin, trans_end, cons_end;
 #endif
 
@@ -761,7 +761,7 @@ int NS_DIM_PREFIX TransferGridFromLevel (MULTIGRID *theMG, INT level)
   Set_Current_BVP(theMG->theBVP);
 
   ASSERT(AllocateControlEntry(NODE_CW,NO_DELETE_OVERLAP2_LEN,&ce_NO_DELETE_OVERLAP2) == GM_OK);
-  for (g=0; g<=TOPLEVEL(theMG); g++)
+  for (INT g=0; g<=TOPLEVEL(theMG); g++)
   {
     GRID *theGrid = GRID_ON_LEVEL(theMG,g);
     for( node=PFIRSTNODE(theGrid); node!= NULL; node=SUCCN(node) )
@@ -769,8 +769,6 @@ int NS_DIM_PREFIX TransferGridFromLevel (MULTIGRID *theMG, INT level)
   }
 #endif
 
-  if (DisposeBottomHeapTmpMemory(theMG)) REP_ERR_RETURN(1);
-
 #ifdef STAT_OUT
   trans_begin = CURRENT_TIME;
 #endif
@@ -789,11 +787,17 @@ int NS_DIM_PREFIX TransferGridFromLevel (MULTIGRID *theMG, INT level)
     ComputeGhostCmds(theMG);
 
     /* send all grids */
-    /*		for (g=TOPLEVEL(theMG); g>=0; g--) */
-    for (g=0; g<=TOPLEVEL(theMG); g++)
+    for (INT g=0; g<=TOPLEVEL(theMG); g++)
     {
       GRID *theGrid = GRID_ON_LEVEL(theMG,g);
-      if (NT(theGrid)>0) migrated += XferGridWithOverlap(theGrid);
+      if (NT(theGrid)>0)
+      {
+#ifdef STAT_OUT
+        migrated += XferGridWithOverlap(theGrid);
+#else
+        XferGridWithOverlap(theGrid);
+#endif
+      }
     }
   }
 
@@ -804,7 +808,7 @@ int NS_DIM_PREFIX TransferGridFromLevel (MULTIGRID *theMG, INT level)
 #endif
 
 #ifdef __OVERLAP2__
-  for (g=0; g<=TOPLEVEL(theMG); g++)
+  for (INT g=0; g<=TOPLEVEL(theMG); g++)
   {
     GRID *theGrid = GRID_ON_LEVEL(theMG,g);
     for( node=PFIRSTNODE(theGrid); node!= NULL; node=SUCCN(node) )
@@ -819,10 +823,6 @@ int NS_DIM_PREFIX TransferGridFromLevel (MULTIGRID *theMG, INT level)
               with grid distribution phase. */
   ConstructConsistentMultiGrid(theMG);
 
-    #ifndef __EXCHANGE_CONNECTIONS__
-  MGCreateConnection(theMG);
-        #endif
-
   /* the grid has changed at least on one processor, thus reset MGSTATUS on all processors */
   RESETMGSTATUS(theMG);
 
